@@ -15,8 +15,8 @@
 import abc
 import collections
 import functools
-from random import randint
 import re
+import secrets
 import threading
 import uuid
 
@@ -69,12 +69,10 @@ def _sync_lock(f):
     return wrapped
 
 
-# TODO(jlibosva): Remove the decorator after we depend on OVN version that has
-# the schema containing the additional_chassis column
 def _match_only_if_additional_chassis_is_supported(f):
     @functools.wraps(f)
     def wrapped(self, row, old):
-        if not hasattr(row, 'additional_chassis'):
+        if not ovn_utils.is_additional_chassis_supported(self.agent.sb_idl):
             return False
         return f(self, row, old)
     return wrapped
@@ -196,10 +194,8 @@ class PortBindingUpdatedEvent(PortBindingEvent):
             ovn_const.OVN_CIDRS_EXT_ID_KEY, "")
         old_cidrs = old.external_ids.get(
             ovn_const.OVN_CIDRS_EXT_ID_KEY, "")
-        # If old_cidrs is "", it is create event,
-        # nothing needs to be done.
         # If old_cidrs equals new_cidrs, the ip does not change.
-        if old_cidrs not in ("", new_cidrs):
+        if old_cidrs != new_cidrs:
             self._log_msg = (
                 "Metadata Port %s in datapath %s updated")
             return True
@@ -208,9 +204,7 @@ class PortBindingUpdatedEvent(PortBindingEvent):
     def _is_new_chassis_set(self, row, old):
         self._log_msg = "Port %s in datapath %s bound to our chassis"
         try:
-            # TODO(jlibosva): Remove the check after we depend on OVN version
-            # that has the schema containing the additional_chassis column
-            if hasattr(row, 'additional_chassis'):
+            if ovn_utils.is_additional_chassis_supported(self.agent.sb_idl):
                 try:
                     # If the additional chassis used to be in the old version
                     # the resources are already provisioned
@@ -365,7 +359,7 @@ class SbGlobalUpdateEvent(_OVNExtensionEvent, row_event.RowEvent):
             # need to spread out the load by introducing a random delay.
             # clamp the max delay between 3 and 10 seconds.
             max_delay = max(min(cfg.CONF.agent_down_time // 3, 10), 3)
-            delay = randint(0, max_delay)
+            delay = secrets.SystemRandom().randint(0, max_delay)
 
         LOG.debug("Delaying updating chassis table for %s seconds", delay)
         timer = threading.Timer(delay, _update_chassis, [self, row])
@@ -382,6 +376,9 @@ class MetadataAgent(object):
             resource_type='metadata')
         self._sb_idl = None
         self._post_fork_event = threading.Event()
+        # We'll restart all haproxy instances upon start so that they honor
+        # any potential changes in their configuration.
+        self.restarted_metadata_proxy_set = set()
         self._chassis = None
 
     @property
@@ -668,14 +665,8 @@ class MetadataAgent(object):
 
         cidrs_to_add = active_subnets_cidrs - current_namespace_cidrs
 
-        # If we were given an IPv6 link-local to configure, add it and the
-        # IPv6 metadata address.
-        metadata_cidrs = [n_const.METADATA_CIDR]
-        if lla and netutils.is_ipv6_enabled():
-            metadata_cidrs.extend([n_const.METADATA_V6_CIDR, lla])
-
-        # Make sure that all required addresses are present
-        for addr in metadata_cidrs:
+        # Make sure that all addresses, including the LLA, are present
+        for addr in (n_const.METADATA_CIDR, n_const.METADATA_V6_CIDR, lla):
             if addr not in current_namespace_cidrs:
                 cidrs_to_add.add(addr)
             else:
@@ -701,7 +692,7 @@ class MetadataAgent(object):
         net_name = ovn_utils.get_network_name_from_datapath(datapath)
         datapath_uuid = str(datapath.uuid)
 
-        metadata_port = self.sb_idl.get_metadata_port_network(datapath_uuid)
+        metadata_port = self.sb_idl.get_metadata_port(datapath_uuid)
         # If there's no metadata port or it doesn't have a MAC address, then
         # tear the namespace down if needed.
         if not (metadata_port and metadata_port.mac):
@@ -744,7 +735,7 @@ class MetadataAgent(object):
             self.teardown_datapath(net_name)
             return
 
-        return net_name, datapath_ports_ip4_ips, any_ip6, metadata_port_info
+        return net_name, datapath_ports_ip4_ips, metadata_port_info
 
     def provision_datapath(self, port_binding):
         """Provision the datapath so that it can serve metadata.
@@ -764,8 +755,7 @@ class MetadataAgent(object):
         provision_params = self._get_provision_params(datapath)
         if not provision_params:
             return
-        net_name, datapath_ports_ip4_ips, any_ip6, metadata_port_info = (
-            provision_params)
+        net_name, datapath_ports_ip4_ips, metadata_port_info = provision_params
 
         LOG.info("Provisioning metadata for network %s", net_name)
         # Create the VETH pair if it's not created. Also the add_veth function
@@ -799,16 +789,11 @@ class MetadataAgent(object):
         ip1.link.set_up()
         ip2.link.set_up()
 
-        # If there is an IPv6 address configured on the port, pass the LLA
-        # to be configured to _process_cidrs()
-        lla = None
-        if any_ip6:
-            lla = ip_lib.get_ipv6_lladdr(metadata_port_info.mac)
         cidrs_to_add, cidrs_to_delete = self._process_cidrs(
             {dev['cidr'] for dev in ip2.addr.list()},
             datapath_ports_ip4_ips,
             metadata_port_info.ip_addresses,
-            lla
+            ip_lib.get_ipv6_lladdr(metadata_port_info.mac)
         )
 
         # Delete any non active addresses from the network namespace
@@ -847,15 +832,14 @@ class MetadataAgent(object):
         # Ensure the correct checksum in the metadata traffic.
         self._ensure_datapath_checksum(namespace)
 
-        # Only if IPv6 is enabled should we listen on the IPv6 metadata
-        # address, same as the dhcp-agent does
-        bind_address_v6 = None
-        if lla and netutils.is_ipv6_enabled():
-            bind_address_v6 = n_const.METADATA_V6_IP
+        if net_name not in self.restarted_metadata_proxy_set:
+            metadata_driver.MetadataDriver.destroy_monitored_metadata_proxy(
+                self._process_monitor, net_name, self.conf, namespace)
+            self.restarted_metadata_proxy_set.add(net_name)
 
         # Spawn metadata proxy if it's not already running.
         metadata_driver.MetadataDriver.spawn_monitored_metadata_proxy(
             self._process_monitor, namespace, n_const.METADATA_PORT,
             self.conf, bind_address=n_const.METADATA_V4_IP,
-            network_id=net_name, bind_address_v6=bind_address_v6,
+            network_id=net_name, bind_address_v6=n_const.METADATA_V6_IP,
             bind_interface=veth_name[1])
