@@ -87,9 +87,5 @@ TRAIT_NETWORK_TUNNEL = 'CUSTOM_NETWORK_TUNNEL_PROVIDER'
 # The lowest binding index for L3 agents and DHCP agents.
 LOWEST_AGENT_BINDING_INDEX = 1
 
-# TODO(haleyb): move this constant to neutron_lib.constants
-IPV4_MIN_MTU = 68
-
-
 # TODO(ralonsoh): move this constant to neutron_lib.plugins.ml2.ovs_constants
 DEFAULT_BR_INT = 'br-int'
