@@ -19,25 +19,6 @@ from neutron.conf.policies import base
 DEPRECATED_REASON = """
 The QoS API now supports project scope and default roles.
 """
-RESOURCE_PATH = '/qos/policies/{id}'
-TAGS_PATH = RESOURCE_PATH + '/tags'
-TAG_PATH = RESOURCE_PATH + '/tags/{tag_id}'
-
-ACTION_GET_TAGS = [
-    {'method': 'GET', 'path': TAGS_PATH},
-    {'method': 'GET', 'path': TAG_PATH},
-]
-ACTION_PUT_TAGS = [
-    {'method': 'PUT', 'path': TAGS_PATH},
-    {'method': 'PUT', 'path': TAG_PATH},
-]
-ACTION_POST_TAGS = [
-    {'method': 'POST', 'path': TAGS_PATH},
-]
-ACTION_DELETE_TAGS = [
-    {'method': 'DELETE', 'path': TAGS_PATH},
-    {'method': 'DELETE', 'path': TAG_PATH},
-]
 
 
 rules = [
@@ -69,19 +50,9 @@ rules = [
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
-    policy.DocumentedRuleDefault(
-        name='get_policies_tags',
-        check_str=neutron_policy.policy_or(
-            base.ADMIN_OR_PROJECT_READER,
-            'rule:shared_qos_policy'
-        ),
-        scope_types=['project'],
-        description='Get QoS policy tags',
-        operations=ACTION_GET_TAGS
-    ),
     policy.DocumentedRuleDefault(
         name='create_policy',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PROJECT_MANAGER,
         scope_types=['project'],
         description='Create a QoS policy',
         operations=[
@@ -96,16 +67,9 @@ rules = [
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
-    policy.DocumentedRuleDefault(
-        name='create_policies_tags',
-        check_str=base.ADMIN,
-        scope_types=['project'],
-        description='Create the QoS policy tags',
-        operations=ACTION_POST_TAGS,
-    ),
     policy.DocumentedRuleDefault(
         name='update_policy',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PROJECT_MANAGER,
         scope_types=['project'],
         description='Update a QoS policy',
         operations=[
@@ -120,16 +84,9 @@ rules = [
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
-    policy.DocumentedRuleDefault(
-        name='update_policies_tags',
-        check_str=base.ADMIN,
-        scope_types=['project'],
-        description='Update the QoS policy tags',
-        operations=ACTION_PUT_TAGS,
-    ),
     policy.DocumentedRuleDefault(
         name='delete_policy',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PROJECT_MANAGER,
         scope_types=['project'],
         description='Delete a QoS policy',
         operations=[
@@ -144,13 +101,6 @@ rules = [
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
-    policy.DocumentedRuleDefault(
-        name='delete_policies_tags',
-        check_str=base.ADMIN,
-        scope_types=['project'],
-        description='Delete the QoS policy tags',
-        operations=ACTION_DELETE_TAGS
-    ),
 
     policy.DocumentedRuleDefault(
         name='get_rule_type',
@@ -202,7 +152,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='create_policy_bandwidth_limit_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Create a QoS bandwidth limit rule',
         operations=[
@@ -219,7 +169,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='update_policy_bandwidth_limit_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Update a QoS bandwidth limit rule',
         operations=[
@@ -237,7 +187,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='delete_policy_bandwidth_limit_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Delete a QoS bandwidth limit rule',
         operations=[
@@ -273,7 +223,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='create_policy_packet_rate_limit_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Create a QoS packet rate limit rule',
         operations=[
@@ -285,7 +235,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='update_policy_packet_rate_limit_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Update a QoS packet rate limit rule',
         operations=[
@@ -298,7 +248,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='delete_policy_packet_rate_limit_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Delete a QoS packet rate limit rule',
         operations=[
@@ -334,7 +284,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='create_policy_dscp_marking_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Create a QoS DSCP marking rule',
         operations=[
@@ -351,7 +301,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='update_policy_dscp_marking_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Update a QoS DSCP marking rule',
         operations=[
@@ -369,7 +319,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='delete_policy_dscp_marking_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Delete a QoS DSCP marking rule',
         operations=[
@@ -410,7 +360,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='create_policy_minimum_bandwidth_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Create a QoS minimum bandwidth rule',
         operations=[
@@ -427,7 +377,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='update_policy_minimum_bandwidth_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Update a QoS minimum bandwidth rule',
         operations=[
@@ -445,7 +395,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='delete_policy_minimum_bandwidth_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Delete a QoS minimum bandwidth rule',
         operations=[
@@ -480,7 +430,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='create_policy_minimum_packet_rate_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Create a QoS minimum packet rate rule',
         operations=[
@@ -492,7 +442,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='update_policy_minimum_packet_rate_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Update a QoS minimum packet rate rule',
         operations=[
@@ -505,7 +455,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='delete_policy_minimum_packet_rate_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Delete a QoS minimum packet rate rule',
         operations=[
@@ -535,7 +485,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='update_alias_bandwidth_limit_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Update a QoS bandwidth limit rule through alias',
         operations=[
@@ -552,7 +502,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='delete_alias_bandwidth_limit_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Delete a QoS bandwidth limit rule through alias',
         operations=[
@@ -586,7 +536,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='update_alias_dscp_marking_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Update a QoS DSCP marking rule through alias',
         operations=[
@@ -603,7 +553,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='delete_alias_dscp_marking_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Delete a QoS DSCP marking rule through alias',
         operations=[
@@ -637,7 +587,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='update_alias_minimum_bandwidth_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Update a QoS minimum bandwidth rule through alias',
         operations=[
@@ -654,7 +604,7 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='delete_alias_minimum_bandwidth_rule',
-        check_str=base.ADMIN,
+        check_str=base.ADMIN_OR_PARENT_OWNER_MANAGER,
         scope_types=['project'],
         description='Delete a QoS minimum bandwidth rule through alias',
         operations=[
