@@ -45,6 +45,9 @@ ACTION_PUT_TAGS = [
     {'method': 'PUT', 'path': TAGS_PATH},
     {'method': 'PUT', 'path': TAG_PATH},
 ]
+ACTION_POST_TAGS = [
+    {'method': 'POST', 'path': TAGS_PATH},
+]
 ACTION_DELETE_TAGS = [
     {'method': 'DELETE', 'path': TAGS_PATH},
     {'method': 'DELETE', 'path': TAG_PATH},
@@ -52,6 +55,12 @@ ACTION_DELETE_TAGS = [
 
 
 rules = [
+    policy.RuleDefault(
+        name='external_network',
+        check_str='field:subnets:router:external=True',
+        description='Definition of a subnet that belongs to an external '
+                    'network'
+    ),
     policy.DocumentedRuleDefault(
         name='create_subnet',
         check_str=base.ADMIN_OR_NET_OWNER_MEMBER,
@@ -92,11 +101,22 @@ rules = [
             deprecated_reason=DEPRECATED_REASON,
             deprecated_since=versionutils.deprecated.WALLABY)
     ),
+    policy.DocumentedRuleDefault(
+        name='create_subnets_tags',
+        check_str=neutron_policy.policy_or(
+            base.PROJECT_MEMBER,
+            base.ADMIN_OR_NET_OWNER_MEMBER,
+        ),
+        scope_types=['project'],
+        description='Create the subnet tags',
+        operations=ACTION_POST_TAGS,
+    ),
     policy.DocumentedRuleDefault(
         name='get_subnet',
         check_str=neutron_policy.policy_or(
             base.PROJECT_READER,
             'rule:shared',
+            'rule:external_network',
             base.ADMIN_OR_NET_OWNER_MEMBER,
         ),
         scope_types=['project'],
@@ -106,6 +126,7 @@ rules = [
             name='get_subnet',
             check_str=neutron_policy.policy_or(
                 'rule:shared',
+                'rule:external_network',
                 neutron_policy.RULE_ADMIN_OR_OWNER,
             ),
             deprecated_reason=DEPRECATED_REASON,
@@ -128,6 +149,7 @@ rules = [
         check_str=neutron_policy.policy_or(
             base.PROJECT_READER,
             'rule:shared',
+            'rule:external_network',
             base.ADMIN_OR_NET_OWNER_MEMBER,
         ),
         scope_types=['project'],
