@@ -21,7 +21,6 @@ from neutron_lib.api.definitions import external_net as extnet_def
 from neutron_lib.api.definitions import ip_allocation as ipalloc_apidef
 from neutron_lib.api.definitions import port as port_def
 from neutron_lib.api.definitions import portbindings as portbindings_def
-from neutron_lib.api.definitions import provider_net as pnet_def
 from neutron_lib.api.definitions import subnetpool as subnetpool_def
 from neutron_lib.api import validators
 from neutron_lib.callbacks import events
@@ -58,7 +57,6 @@ from neutron.common import utils
 from neutron.conf import experimental as c_exp
 from neutron.db import db_base_plugin_common
 from neutron.db import ipam_pluggable_backend
-from neutron.db.models import segment as segment_db
 from neutron.db import models_v2
 from neutron.db import rbac_db_mixin as rbac_mixin
 from neutron.db import rbac_db_models
@@ -132,33 +130,6 @@ def _port_filter_hook(context, original_model, conditions):
     return conditions
 
 
-def _network_result_filter_hook(query, filters):
-    # This filter matches the provider network attributes, defined in
-    # ``neutron_lib.api.definitions.provider_net.ATTRIBUTES``.
-    attr_to_field = {
-        pnet_def.NETWORK_TYPE: segment_db.NetworkSegment.network_type,
-        pnet_def.PHYSICAL_NETWORK: segment_db.NetworkSegment.physical_network,
-        pnet_def.SEGMENTATION_ID: segment_db.NetworkSegment.segmentation_id
-    }
-
-    if any(attr for attr in pnet_def.ATTRIBUTES if attr in filters):
-        query = query.join(
-            segment_db.NetworkSegment,
-            segment_db.NetworkSegment.network_id == models_v2.Network.id)
-    for attr in pnet_def.ATTRIBUTES:
-        if attr not in filters:
-            continue
-
-        value = filters[attr]
-        field = attr_to_field[attr]
-        if utils.is_iterable_not_string(value):
-            query = query.filter(field.in_(value))
-        else:
-            query = query.filter(field == value)
-
-    return query
-
-
 @registry.has_registry_receivers
 class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                         neutron_plugin_base_v2.NeutronPluginBaseV2,
@@ -193,12 +164,6 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             query_hook=_port_query_hook,
             filter_hook=_port_filter_hook,
             result_filters=None)
-        model_query.register_hook(
-            models_v2.Network,
-            'network',
-            query_hook=None,
-            filter_hook=None,
-            result_filters=_network_result_filter_hook)
         return super(NeutronDbPluginV2, cls).__new__(cls, *args, **kwargs)
 
     @staticmethod
@@ -208,7 +173,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 experimental.validate_experimental_enabled(
                     c_exp.EXPERIMENTAL_IPV6_PD)
         except cfg.NoSuchOptError:
-            return
+            pass
 
     def __init__(self):
         self._validate_ipv6_pd()
@@ -311,10 +276,6 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 allowed_tenants.append(net_tenant_id)
                 ports = ports.filter(
                     ~models_v2.Port.tenant_id.in_(allowed_tenants))
-                # Filter any port with project_id=''. These ports are related
-                # to floating IPs, router ports (gateway, SNAT, FIP agent, HA
-                # interface).
-                ports = ports.filter(models_v2.Port.project_id.notin_(['']))
             else:
                 # if there is a wildcard rule, we can return early because it
                 # allows any ports
@@ -552,9 +513,9 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             return
 
         # at least one subnet present, if below IPv4 minimum we fail early
-        if mtu < _constants.IPV4_MIN_MTU:
+        if mtu < constants.IPV4_MIN_MTU:
             raise mtu_exc.NetworkMTUSubnetConflict(
-                net_id=id, mtu=_constants.IPV4_MIN_MTU)
+                net_id=id, mtu=constants.IPV4_MIN_MTU)
 
         # We do not need to check IPv4 subnets as they will have been
         # caught by above IPV4_MIN_MTU check
@@ -833,7 +794,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             return
 
         # if below IPv4 minimum we fail early
-        if mtu < _constants.IPV4_MIN_MTU:
+        if mtu < constants.IPV4_MIN_MTU:
             raise mtu_exc.NetworkMTUSubnetConflict(net_id=network.id, mtu=mtu)
 
         # We do not need to check IPv4 subnets as they will have been
@@ -845,40 +806,10 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
 
     def _update_router_gw_ports(self, context, network, subnet):
         l3plugin = directory.get_plugin(plugin_constants.L3)
-        if l3plugin:
-            gw_ports = self._get_router_gw_ports_by_network(context,
-                                                            network['id'])
-            router_ids = [p.device_id for p in gw_ports]
-            for id in router_ids:
-                try:
-                    self._update_router_gw_port(context, id, network, subnet)
-                except l3_exc.RouterNotFound:
-                    LOG.debug("Router %(id)s was concurrently deleted while "
-                              "updating GW port for subnet %(s)s",
-                              {'id': id, 's': subnet})
-
-    def _update_router_gw_port(self, context, router_id, network, subnet):
-        l3plugin = directory.get_plugin(plugin_constants.L3)
-        ctx_admin = context.elevated()
-        ext_subnets_dict = {s['id']: s for s in network['subnets']}
-        router = l3plugin.get_router(ctx_admin, router_id)
-        external_gateway_info = router['external_gateway_info']
-        # Get all stateful (i.e. non-SLAAC/DHCPv6-stateless) fixed ips
-        fips = [f for f in external_gateway_info['external_fixed_ips']
-                if not ipv6_utils.is_auto_address_subnet(
-                    ext_subnets_dict[f['subnet_id']])]
-        num_fips = len(fips)
-        # Don't add the fixed IP to the port if it already
-        # has a stateful fixed IP of the same IP version
-        if num_fips > 1:
-            return
-        if num_fips == 1 and netaddr.IPAddress(
-                fips[0]['ip_address']).version == subnet['ip_version']:
-            return
-        external_gateway_info['external_fixed_ips'].append(
-            {'subnet_id': subnet['id']})
-        info = {'router': {'external_gateway_info': external_gateway_info}}
-        l3plugin.update_router(ctx_admin, router_id, info)
+        # The hasattr check for customized l3 plugins that may have no such
+        # function.
+        if l3plugin and hasattr(l3plugin, "update_router_gw_ports"):
+            l3plugin.update_router_gw_ports(context, network, subnet)
 
     @db_api.retry_if_session_inactive()
     def _create_subnet_postcommit(self, context, result,
@@ -1695,8 +1626,8 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         port = self._get_port(context, id, lazy_fields=lazy_fields)
         return self._make_port_dict(port, fields)
 
-    def _get_ports_query(self, context, filters=None, lazy_fields=None,
-                         *args, **kwargs):
+    def _get_ports_query(self, context, *args, filters=None, lazy_fields=None,
+                         **kwargs):
         Port = models_v2.Port
         IPAllocation = models_v2.IPAllocation
 
@@ -1752,7 +1683,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
     @db_api.retry_if_session_inactive()
     @db_api.CONTEXT_READER
     def get_ports_count(self, context, filters=None):
-        return self._get_ports_query(context, filters).count()
+        return self._get_ports_query(context, filters=filters).count()
 
     def _enforce_device_owner_not_router_intf_or_device_id(self, context,
                                                            device_owner,
