@@ -47,6 +47,7 @@ from oslo_utils import timeutils
 from ovsdbapp.backend.ovs_idl import idlutils
 
 from neutron._i18n import _
+from neutron.api import wsgi
 from neutron.common.ovn import acl as ovn_acl
 from neutron.common.ovn import constants as ovn_const
 from neutron.common.ovn import exceptions as ovn_exceptions
@@ -72,7 +73,6 @@ from neutron.services.logapi.drivers.ovn import driver as log_driver
 from neutron.services.qos.drivers.ovn import driver as qos_driver
 from neutron.services.segments import db as segment_service_db
 from neutron.services.trunk.drivers.ovn import trunk_driver
-import neutron.wsgi
 
 
 LOG = log.getLogger(__name__)
@@ -257,7 +257,7 @@ class OVNMechanismDriver(api.MechanismDriver):
                            resources.SEGMENT,
                            events.AFTER_DELETE)
 
-        # Handle security group/rule or address group notifications
+        # Handle security group/rule notifications
         if self.sg_enabled:
             registry.subscribe(self._create_security_group_precommit,
                                resources.SECURITY_GROUP,
@@ -283,15 +283,6 @@ class OVNMechanismDriver(api.MechanismDriver):
             registry.subscribe(self._process_sg_rule_notification,
                                resources.SECURITY_GROUP_RULE,
                                events.BEFORE_DELETE)
-            registry.subscribe(self._process_ag_notification,
-                               resources.ADDRESS_GROUP,
-                               events.AFTER_CREATE)
-            registry.subscribe(self._process_ag_notification,
-                               resources.ADDRESS_GROUP,
-                               events.AFTER_UPDATE)
-            registry.subscribe(self._process_ag_notification,
-                               resources.ADDRESS_GROUP,
-                               events.AFTER_DELETE)
 
     def _remove_node_from_hash_ring(self, *args, **kwargs):
         # The node_uuid attribute will be empty for worker types
@@ -308,7 +299,7 @@ class OVNMechanismDriver(api.MechanismDriver):
 
     @staticmethod
     def should_post_fork_initialize(worker_class):
-        return worker_class in (neutron.wsgi.WorkerService,
+        return worker_class in (wsgi.WorkerService,
                                 worker.MaintenanceWorker,
                                 service.RpcWorker)
 
@@ -353,7 +344,7 @@ class OVNMechanismDriver(api.MechanismDriver):
         self._post_fork_event.clear()
         self._ovn_client_inst = None
 
-        if worker_class == neutron.wsgi.WorkerService:
+        if worker_class == wsgi.WorkerService:
             self._setup_hash_ring()
 
         n_agent.AgentCache(self)  # Initialize singleton agent cache
@@ -413,11 +404,6 @@ class OVNMechanismDriver(api.MechanismDriver):
             context, security_group['id'],
             ovn_const.TYPE_SECURITY_GROUPS,
             std_attr_id=security_group['standard_attr_id'])
-        for sg_rule in security_group['security_group_rules']:
-            ovn_revision_numbers_db.create_initial_revision(
-                context, sg_rule['id'],
-                ovn_const.TYPE_SECURITY_GROUP_RULES,
-                std_attr_id=sg_rule['standard_attr_id'])
 
     def _create_security_group(self, resource, event, trigger, payload):
         context = payload.context
@@ -511,25 +497,6 @@ class OVNMechanismDriver(api.MechanismDriver):
                 return True
         return False
 
-    def _process_ag_notification(
-            self, resource, event, trigger, payload):
-        context = payload.context
-        address_group = payload.latest_state
-        address_group_id = payload.resource_id
-        if event == events.AFTER_CREATE:
-            ovn_revision_numbers_db.create_initial_revision(
-                context, address_group_id, ovn_const.TYPE_ADDRESS_GROUPS,
-                std_attr_id=address_group['standard_attr_id'])
-            self._ovn_client.create_address_group(
-                context, address_group)
-        elif event == events.AFTER_UPDATE:
-            self._ovn_client.update_address_group(
-                context, address_group)
-        elif event == events.AFTER_DELETE:
-            self._ovn_client.delete_address_group(
-                context,
-                address_group_id)
-
     def _is_network_type_supported(self, network_type):
         return (network_type in [const.TYPE_LOCAL,
                                  const.TYPE_FLAT,
@@ -1237,9 +1204,9 @@ class OVNMechanismDriver(api.MechanismDriver):
                 self.sb_ovn.get_extport_chassis_from_cms_options()):
             try:
                 with self.nb_ovn.transaction(check_error=True) as txn:
-                    ovn_utils.sync_ha_chassis_group(
-                        admin_context, db_port['id'], db_port['network_id'],
-                        self.nb_ovn, self.sb_ovn, txn)
+                    ovn_utils.sync_ha_chassis_group_network(
+                        admin_context, self.nb_ovn, self.sb_ovn,
+                        db_port['id'], db_port['network_id'], txn)
             except Exception as e:
                 LOG.error('Error while syncing the HA Chassis Group for the '
                           'external port %s during set port status up. '
@@ -1518,6 +1485,11 @@ def delete_agent(self, context, id, _driver=None):
         'SB_Global', '.', 'external_ids', delete_agent=str(id),
         if_exists=True).execute(check_error=True)
 
+    try:
+        n_agent.AgentCache().delete(id)
+    except KeyError:
+        LOG.debug('OVN agent %s has been deleted concurrently', id)
+
 
 def get_availability_zones(cls, context, _driver, filters=None, fields=None,
                            sorts=None, limit=None, marker=None,
