@@ -36,7 +36,6 @@ RESOURCE_TYPE_MAP = {
     ovn_const.TYPE_ROUTER_PORTS: 'Logical_Router_Port',
     ovn_const.TYPE_FLOATINGIPS: 'NAT',
     ovn_const.TYPE_SUBNETS: 'DHCP_Options',
-    ovn_const.TYPE_ADDRESS_GROUPS: 'Address_Set',
 }
 
 
@@ -419,6 +418,17 @@ class ScheduleNewGatewayCommand(command.BaseCommand):
                     *_add_gateway_chassis(self.api, txn, self.g_name, chassis))
 
 
+class LrDelCommand(ovn_nb_commands.LrDelCommand):
+
+    def run_idl(self, txn):
+        super().run_idl(txn)
+        try:
+            hcg = self.api.lookup('HA_Chassis_Group', self.router)
+            hcg.delete()
+        except idlutils.RowNotFound:
+            pass
+
+
 class AddLRouterPortCommand(command.BaseCommand):
     def __init__(self, api, name, lrouter, may_exist, **columns):
         super(AddLRouterPortCommand, self).__init__(api)
@@ -665,12 +675,11 @@ class AddStaticRouteCommand(command.BaseCommand):
         _addvalue_to_list(lrouter, 'static_routes', row.uuid)
 
 
-class DelStaticRouteCommand(command.BaseCommand):
-    def __init__(self, api, lrouter, ip_prefix, nexthop, if_exists):
-        super(DelStaticRouteCommand, self).__init__(api)
+class DelStaticRoutesCommand(command.BaseCommand):
+    def __init__(self, api, lrouter, routes, if_exists):
+        super(DelStaticRoutesCommand, self).__init__(api)
         self.lrouter = lrouter
-        self.ip_prefix = ip_prefix
-        self.nexthop = nexthop
+        self.routes = routes
         self.if_exists = if_exists
 
     def run_idl(self, txn):
@@ -683,14 +692,33 @@ class DelStaticRouteCommand(command.BaseCommand):
             msg = _("Logical Router %s does not exist") % self.lrouter
             raise RuntimeError(msg)
 
-        static_routes = getattr(lrouter, 'static_routes', [])
-        for route in static_routes:
-            ip_prefix = getattr(route, 'ip_prefix', '')
-            nexthop = getattr(route, 'nexthop', '')
-            if self.ip_prefix == ip_prefix and self.nexthop == nexthop:
-                _delvalue_from_list(lrouter, 'static_routes', route)
-                route.delete()
-                break
+        routes_to_be_deleted = []
+        for route in getattr(lrouter, 'static_routes', []):
+            route_tuple = (getattr(route, 'ip_prefix', ''),
+                           getattr(route, 'nexthop', ''))
+            if route_tuple in self.routes:
+                routes_to_be_deleted.append(route)
+
+        for route in routes_to_be_deleted:
+            _delvalue_from_list(lrouter, 'static_routes', route)
+            route.delete()
+
+
+class SetStaticRouteCommand(command.BaseCommand):
+    def __init__(self, api, sroute, **columns):
+        super().__init__(api)
+        self.sroute = sroute
+        self.columns = columns
+
+    def run_idl(self, txn):
+        try:
+            for col, val in self.columns.items():
+                setattr(self.sroute, col, val)
+
+        except idlutils.RowNotFound:
+            msg = (_('Logical Router Static Route %s does not exist')
+                   % self.sroute)
+            raise RuntimeError(msg)
 
 
 class UpdateObjectExtIdsCommand(command.BaseCommand):
@@ -976,6 +1004,15 @@ class DeleteLRouterExtGwCommand(command.BaseCommand):
             lrouter.delvalue('nat', nat)
             nat.delete()
 
+        # Remove the router pinning to a chassis (if any).
+        lrouter.delkey('options', 'chassis')
+
+        # Remove the HA_Chassis_Group of the router (if any).
+        hcg = self.api.lookup('HA_Chassis_Group',
+                              lrouter.name, default=None)
+        if hcg:
+            hcg.delete()
+
         for gw_port in self.api.get_lrouter_gw_ports(lrouter.name):
             lrouter.delvalue('ports', gw_port)
 
