@@ -369,6 +369,24 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
                            'dnat_and_snats': dnat_and_snats})
         return result
 
+    def get_all_logical_routers_static_routes(self):
+        """Get static routes associated with all logical Routers
+
+        @return: list of dict, each dict has key-value:
+                 - 'name': string router_id in neutron.
+                 - 'static_routes': list of static routes rows.
+        """
+        result = []
+        for lrouter in self._tables['Logical_Router'].rows.values():
+            if (ovn_const.OVN_ROUTER_NAME_EXT_ID_KEY not in
+                    lrouter.external_ids):
+                continue
+            result.append({'name': lrouter.name.replace('neutron-', ''),
+                           'static_routes': getattr(lrouter, 'static_routes',
+                                                    [])})
+
+        return result
+
     def get_acl_by_id(self, acl_id):
         try:
             return self.lookup('ACL', uuid.UUID(acl_id))
@@ -428,6 +446,11 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         return cmd.UpdateLRouterCommand(self, name,
                                         if_exists, **columns)
 
+    # This method overrides the parent class ``nb_impl_idl.OvnNbApiIdlImpl``
+    # implementation.
+    def lr_del(self, router, if_exists=False):
+        return cmd.LrDelCommand(self, router, if_exists=if_exists)
+
     def add_lrouter_port(self, name, lrouter, may_exist=False, **columns):
         return cmd.AddLRouterPortCommand(self, name, lrouter,
                                          may_exist, **columns)
@@ -469,9 +492,11 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
         return cmd.AddStaticRouteCommand(self, lrouter, maintain_bfd,
                                          **columns)
 
-    def delete_static_route(self, lrouter, ip_prefix, nexthop, if_exists=True):
-        return cmd.DelStaticRouteCommand(self, lrouter, ip_prefix, nexthop,
-                                         if_exists)
+    def delete_static_routes(self, lrouter, routes, if_exists=True):
+        return cmd.DelStaticRoutesCommand(self, lrouter, routes, if_exists)
+
+    def set_static_route(self, sroute, **columns):
+        return cmd.SetStaticRouteCommand(self, sroute, **columns)
 
     def _get_logical_router_port_gateway_chassis(self, lrp, priorities=None):
         """Get the list of chassis hosting this gateway port.
@@ -954,10 +979,10 @@ class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
                      card_serial_number)
         raise RuntimeError(msg)
 
-    def get_metadata_port_network(self, network):
+    def get_metadata_port(self, datapath_uuid):
         # TODO(twilson) This function should really just take a Row/RowView
         try:
-            dp = self.lookup('Datapath_Binding', uuid.UUID(network))
+            dp = self.lookup('Datapath_Binding', uuid.UUID(datapath_uuid))
         except idlutils.RowNotFound:
             return None
         cmd = self.db_find_rows('Port_Binding', ('datapath', '=', dp),
