@@ -19,6 +19,7 @@ import inspect
 import threading
 
 from futurist import periodics
+from neutron_lib.api.definitions import external_net
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import provider_net as pnet
 from neutron_lib import constants as n_const
@@ -207,13 +208,6 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                 'ovn_update': self._ovn_client.update_router,
                 'ovn_delete': self._ovn_client.delete_router,
             },
-            ovn_const.TYPE_ADDRESS_GROUPS: {
-                'neutron_get': self._ovn_client._plugin.get_address_group,
-                'ovn_get': self._nb_idl.get_address_set,
-                'ovn_create': self._ovn_client.create_address_group,
-                'ovn_update': self._ovn_client.update_address_group,
-                'ovn_delete': self._ovn_client.delete_address_group,
-            },
             ovn_const.TYPE_SECURITY_GROUPS: {
                 'neutron_get': self._ovn_client._plugin.get_security_group,
                 'ovn_get': self._nb_idl.get_port_group,
@@ -283,29 +277,6 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                     # supposed to be.
                     revision_numbers_db.bump_revision(context, n_obj,
                                                       row.resource_type)
-                elif row.resource_type == ovn_const.TYPE_ADDRESS_GROUPS:
-                    need_bump = False
-                    for obj in ovn_obj:
-                        if not obj:
-                            # NOTE(liushy): We create two Address_Sets for
-                            # one Address_Group at one ovn_create func.
-                            res_map['ovn_create'](context, n_obj)
-                            need_bump = False
-                            break
-                        ext_ids = getattr(obj, 'external_ids', {})
-                        ovn_revision = int(ext_ids.get(
-                            ovn_const.OVN_REV_NUM_EXT_ID_KEY, -1))
-                        # NOTE(liushy): We have created two Address_Sets
-                        # for one Address_Group, and we update both of
-                        # them at one ovn_update func.
-                        if ovn_revision != n_obj['revision_number']:
-                            res_map['ovn_update'](context, n_obj)
-                            need_bump = False
-                            break
-                        need_bump = True
-                    if need_bump:
-                        revision_numbers_db.bump_revision(context, n_obj,
-                                                          row.resource_type)
                 else:
                     ext_ids = getattr(ovn_obj, 'external_ids', {})
                     ovn_revision = int(ext_ids.get(
@@ -611,9 +582,9 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                 network_id = port.external_ids[
                     ovn_const.OVN_NETWORK_NAME_EXT_ID_KEY].replace(
                         ovn_const.OVN_NAME_PREFIX, '')
-                ha_ch_grp = utils.sync_ha_chassis_group(
-                    context, port.name, network_id, self._nb_idl,
-                    self._sb_idl, txn)
+                ha_ch_grp, high_prio_ch = utils.sync_ha_chassis_group_network(
+                    context, self._nb_idl, self._sb_idl, port.name,
+                    network_id, txn)
                 txn.add(self._nb_idl.set_lswitch_port(
                     port.name, ha_chassis_group=ha_ch_grp))
 
@@ -727,6 +698,10 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         gw_ports = self._ovn_client._plugin.get_ports(
             context, {'device_owner': [n_const.DEVICE_OWNER_ROUTER_GW]})
         for gw_port in gw_ports:
+            router = self._ovn_client._l3_plugin.get_router(
+                context, gw_port['device_id'])
+            if not utils.is_ovn_provider_router(router):
+                continue
             enable_redirect = False
             if ovn_conf.is_ovn_distributed_floating_ip():
                 try:
@@ -953,40 +928,6 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
         raise periodics.NeverAgain()
 
-    # TODO(ralonsoh): Remove this in the Z+4 cycle
-    @has_lock_periodic(spacing=600, run_immediately=True)
-    def update_port_virtual_type(self):
-        """Set type=virtual to those ports with parents
-        Before LP#1973276, any virtual port with "device_owner" defined, lost
-        its type=virtual. This task restores the type for those ports updated
-        before the fix https://review.opendev.org/c/openstack/neutron/+/841711.
-        """
-        context = n_context.get_admin_context()
-        cmds = []
-        for lsp in self._nb_idl.lsp_list().execute(check_error=True):
-            if lsp.type != '':
-                continue
-
-            try:
-                port = self._ovn_client._plugin.get_port(context, lsp.name)
-            except n_exc.PortNotFound:
-                continue
-
-            for ip in port.get('fixed_ips', []):
-                if utils.get_virtual_port_parents(
-                        self._nb_idl, ip['ip_address'], port['network_id'],
-                        port['id']):
-                    cmds.append(self._nb_idl.db_set(
-                        'Logical_Switch_Port', lsp.uuid,
-                        ('type', ovn_const.LSP_TYPE_VIRTUAL)))
-                    break
-
-        if cmds:
-            with self._nb_idl.transaction(check_error=True) as txn:
-                for cmd in cmds:
-                    txn.add(cmd)
-        raise periodics.NeverAgain()
-
     # TODO(ralonsoh): Remove this in the Antelope+4 cycle
     @has_lock_periodic(
         periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
@@ -1020,7 +961,9 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         """Add info if LRP is connecting internal subnet or ext gateway."""
         cmds = []
         context = n_context.get_admin_context()
-        for router in self._ovn_client._l3_plugin.get_routers(context):
+        filters = {'flavor_id': [None]}
+        for router in self._ovn_client._l3_plugin.get_routers(context,
+                                                              filters=filters):
             ext_gw_networks = [
                 ext_gw['network_id'] for ext_gw in router['external_gateways']]
             rtr_name = 'neutron-{}'.format(router['id'])
@@ -1060,14 +1003,16 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
         for router in self._nb_idl.lr_list().execute(check_error=True):
             if not router.external_ids.get(ovn_const.OVN_REV_NUM_EXT_ID_KEY):
                 continue
-            for route in self._nb_idl.lr_route_list(router.uuid).execute(
-                    check_error=True):
-                if (route.nexthop == '' and
-                        route.ip_prefix in (n_const.IPv4_ANY,
-                                            n_const.IPv6_ANY)):
-                    cmds.append(
-                        self._nb_idl.delete_static_route(
-                            router.name, route.ip_prefix, ''))
+            routes_to_delete = [
+                (r.ip_prefix, '')
+                for r in self._nb_idl.lr_route_list(router.uuid).execute(
+                    check_error=True)
+                if r.nexthop == '' and r.ip_prefix in (n_const.IPv4_ANY,
+                                                       n_const.IPv6_ANY)
+            ]
+            cmds.append(
+                self._nb_idl.delete_static_routes(router.name,
+                                                  routes_to_delete))
 
         if cmds:
             with self._nb_idl.transaction(check_error=True) as txn:
@@ -1131,63 +1076,6 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
                                                    from_reload=True)
         raise periodics.NeverAgain()
 
-    @periodics.periodic(spacing=300, run_immediately=True)
-    def remove_duplicated_chassis_registers(self):
-        """Remove the "Chassis" and "Chassis_Private" duplicated registers.
-
-        When the ovn-controller service of a node is updated and the system-id
-        is changed, if the old service is not stopped gracefully, it will leave
-        a "Chassis" and a "Chassis_Private" registers on the OVN SB database.
-        These leftovers must be removed.
-
-        NOTE: this method is executed every 5 minutes. If a new chassis is
-        added, this method will perform again the clean-up process.
-
-        NOTE: this method can be executed only if the OVN SB has the
-        "Chassis_Private" table. Otherwise, is not possible to find out which
-        register is newer and thus must be kept in the database.
-        """
-        if not self._sb_idl.is_table_present('Chassis_Private'):
-            raise periodics.NeverAgain()
-
-        if not self.has_lock:
-            return
-
-        # dup_chassis_port_host = {host_name: [(ch1, ch_private1),
-        #                                      (ch2, ch_private2), ... ]}
-        dup_chassis_port_host = {}
-        chassis = self._sb_idl.chassis_list().execute(check_error=True)
-        chassis_hostnames = {ch.hostname for ch in chassis}
-        # Find the duplicated "Chassis" and "Chassis_Private" registers,
-        # comparing the hostname.
-        for hostname in chassis_hostnames:
-            ch_list = []
-            # Find these chassis matching the hostname and create a list.
-            for ch in (ch for ch in chassis if ch.hostname == hostname):
-                ch_private = self._sb_idl.lookup('Chassis_Private', ch.name,
-                                                 default=None)
-                if ch_private:
-                    ch_list.append((ch, ch_private))
-
-            # If the chassis list > 1, then we have duplicated chassis.
-            if len(ch_list) > 1:
-                # Order ch_list by Chassis_Private.nb_cfg_timestamp, from newer
-                # (greater value) to older.
-                ch_list.sort(key=lambda x: x[1].nb_cfg_timestamp, reverse=True)
-                dup_chassis_port_host[hostname] = ch_list
-
-        if not dup_chassis_port_host:
-            return
-
-        # Remove the "Chassis" and "Chassis_Private" registers with the
-        # older Chassis_Private.nb_cfg_timestamp.
-        with self._sb_idl.transaction(check_error=True) as txn:
-            for ch_list in dup_chassis_port_host.values():
-                # The first item is skipped, this is the newest element.
-                for ch, ch_private in ch_list[1:]:
-                    for table in ('Chassis_Private', 'Chassis'):
-                        txn.add(self._sb_idl.db_destroy(table, ch.name))
-
     @has_lock_periodic(spacing=86400, run_immediately=True)
     def cleanup_old_hash_ring_nodes(self):
         """Daily task to cleanup old stable Hash Ring node entries.
@@ -1332,23 +1220,11 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
         raise periodics.NeverAgain()
 
+    # TODO(ralonsoh): Remove this method in the E cycle (SLURP release)
     @has_lock_periodic(
         periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
         spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
         run_immediately=True)
-    def set_fip_distributed_flag(self):
-        """Set the NB_Global.external_ids:fip-distributed flag."""
-        distributed = ovn_conf.is_ovn_distributed_floating_ip()
-        LOG.debug(
-            "Setting fip-distributed flag in NB_Global to %s", distributed)
-        self._nb_idl.db_set(
-            'NB_Global', '.', external_ids={
-                ovn_const.OVN_FIP_DISTRIBUTED_KEY: str(distributed)}).execute(
-                    check_error=True)
-        raise periodics.NeverAgain()
-
-    # TODO(ralonsoh): Remove this method in the E cycle (SLURP release)
-    @has_lock_periodic(spacing=600, run_immediately=True)
     def set_network_type(self):
         """Add the network type to the Logical_Switch registers"""
         context = n_context.get_admin_context()
@@ -1371,6 +1247,85 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
         raise periodics.NeverAgain()
 
+    @has_lock_periodic(
+        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
+        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
+        run_immediately=True)
+    def check_network_broadcast_arps_to_all_routers(self):
+        """Check the broadcast-arps-to-all-routers config
+
+        Ensure that the broadcast-arps-to-all-routers is set accordingly
+        to the ML2/OVN configuration option.
+        """
+        context = n_context.get_admin_context()
+        networks = self._ovn_client._plugin.get_networks(
+            context, filters={external_net.EXTERNAL: [True]})
+        cmds = []
+        for net in networks:
+            ls_name = utils.ovn_name(net['id'])
+            ls = self._nb_idl.get_lswitch(ls_name)
+            broadcast_value = ls.other_config.get(
+                ovn_const.LS_OPTIONS_BROADCAST_ARPS_ROUTERS)
+            expected_broadcast_value = ('true'
+                if ovn_conf.is_broadcast_arps_to_all_routers_enabled() else
+                'false')
+            # Assert the config value is the right one
+            if broadcast_value == expected_broadcast_value:
+                continue
+            # If not, set the right value
+            other_config = {ovn_const.LS_OPTIONS_BROADCAST_ARPS_ROUTERS:
+                            expected_broadcast_value}
+            cmds.append(self._nb_idl.db_set('Logical_Switch', ls_name,
+                                            ('other_config', other_config)))
+        if cmds:
+            with self._nb_idl.transaction(check_error=True) as txn:
+                for cmd in cmds:
+                    txn.add(cmd)
+        raise periodics.NeverAgain()
+
+    # TODO(racosta): Remove this method in the E+2 cycle (SLURP release)
+    @has_lock_periodic(spacing=600, run_immediately=True)
+    def update_router_static_routes(self):
+        """Set external_ids column to any Neutron's owned static route.
+        """
+
+        context = n_context.get_admin_context()
+        sroute_update = []
+        lrouters = self._nb_idl.get_all_logical_routers_static_routes()
+        for router in lrouters:
+            sroutes = router['static_routes']
+            for sroute in sroutes:
+                # Skip Static Routes that are already configured with an
+                # external_id key
+                if (ovn_const.OVN_LRSR_EXT_ID_KEY not in
+                        sroute.external_ids.keys()):
+                    sroute_update.append({'sroute': sroute,
+                                          'name': router['name']})
+
+        routes_cache = {}
+        cmds = []
+        columns = {'external_ids': {ovn_const.OVN_LRSR_EXT_ID_KEY: 'true'}}
+        for sroute in sroute_update:
+            lrouter = utils.ovn_name(sroute['name'])
+            if lrouter not in routes_cache.keys():
+                router_db = self._ovn_client._l3_plugin.get_router(context,
+                    sroute['name'], fields=['routes'])
+                routes_cache[lrouter] = router_db.get('routes')
+
+            ovn_route = sroute['sroute']
+            for db_route in routes_cache[lrouter]:
+                if (ovn_route.ip_prefix == db_route['destination'] and
+                        ovn_route.nexthop == db_route['nexthop']):
+                    cmds.append(self._nb_idl.set_static_route(sroute['sroute'],
+                                                              **columns))
+                    break
+
+        if cmds:
+            with self._nb_idl.transaction(check_error=True) as txn:
+                for cmd in cmds:
+                    txn.add(cmd)
+        raise periodics.NeverAgain()
+
 
 class HashRingHealthCheckPeriodics(object):
 
