@@ -15,6 +15,7 @@
 import abc
 import datetime
 
+from neutron_lib import constants as n_const
 from neutron_lib import context as neutron_context
 from neutron_lib.plugins import constants
 from neutron_lib.plugins import directory
@@ -34,6 +35,7 @@ from neutron.common.ovn import hash_ring_manager
 from neutron.common.ovn import utils
 from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf
 from neutron.db import ovn_hash_ring_db
+from neutron.objects import router as router_obj
 from neutron.plugins.ml2.drivers.ovn.agent import neutron_agent as n_agent
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb.extensions import \
     placement
@@ -327,7 +329,7 @@ class ChassisAgentDeleteEvent(ChassisAgentEvent):
             return False
 
     def run(self, event, row, old):
-        n_agent.AgentCache().delete(row.external_ids['delete_agent'])
+        n_agent.AgentCache().delete([row.external_ids['delete_agent']])
 
 
 class ChassisAgentWriteEvent(ChassisAgentEvent):
@@ -539,6 +541,63 @@ class LogicalSwitchPortUpdateDownEvent(row_event.RowEvent):
         self.driver.set_port_status_down(row.name)
 
 
+class LogicalSwitchPortUpdateLogicalRouterPortEvent(row_event.RowEvent):
+    """Row update event - Logical_Switch_Port, that updates the sibling LRP"""
+    def __init__(self, driver):
+        self.driver = driver
+        table = 'Logical_Switch_Port'
+        events = (self.ROW_UPDATE,)
+        super().__init__(events, table, None)
+        self.event_name = 'LogicalSwitchPortUpdateLogicalRouterPortEvent'
+        self.l3_plugin = directory.get_plugin(constants.L3)
+        self.admin_context = neutron_context.get_admin_context()
+
+    def match_fn(self, event, row, old):
+        device_id = row.external_ids.get(ovn_const.OVN_DEVID_EXT_ID_KEY)
+        device_owner = row.external_ids.get(
+            ovn_const.OVN_DEVICE_OWNER_EXT_ID_KEY)
+        if (not device_id or
+                device_owner not in n_const.ROUTER_INTERFACE_OWNERS):
+            # This LSP does not belong to a router.
+            return False
+
+        lrp_name = utils.ovn_lrouter_port_name(row.name)
+        if not self.driver.nb_ovn.lookup('Logical_Router_Port', lrp_name,
+                                         default=None):
+            # The LRP has not been created yet.
+            return False
+
+        # TODO(ralonsoh): store the router "flavor_id" in the LSP.external_ids
+        # or the LRP.external_ids (better the second).
+        router = router_obj.Router.get_object(self.admin_context, id=device_id,
+                                              fields=('flavor_id', ))
+        if (utils.is_lsp_router_port(lsp=row) and
+                router and
+                utils.is_ovn_provider_router(router)):
+            return True
+        return False
+
+    def run(self, event, row, old):
+        # In some cases, it is possible for the logical switch port to be
+        # already removed from db by some other concurrent event when this
+        # method is called. Therefore, use get_ports to just query for this
+        # port instead of directly trying to get it from db causing not
+        # found exception.
+        ports = self.driver._plugin.get_ports(
+            self.admin_context,
+            filters={'id': [row.name]})
+        if ports:
+            self.l3_plugin._ovn_client.update_router_port(
+                self.admin_context,
+                ports[0])
+        else:
+            LOG.debug('Port %(port_id)s not found when '
+                      'run of %(event_name)s was called. '
+                      'Router port was not updated.',
+                      {'port_id': row.name,
+                       'event_name': self.event_name})
+
+
 class PortBindingUpdateVirtualPortsEvent(row_event.RowEvent):
     """Row update event - Port_Binding for virtual ports
 
@@ -619,6 +678,52 @@ class FIPAddDeleteEvent(row_event.RowEvent):
         self.driver.delete_mac_binding_entries(row.external_ip)
 
 
+class HAChassisGroupRouterEvent(row_event.RowEvent):
+    """Row update event - the HA_Chassis list changes in a router HCG
+
+    When the HA_Chassis list changes (a chassis has been added, deleted or
+    updated), those routers with a HA_Chassis_Group related should update the
+    "LR.options.chassis" value.
+    """
+    def __init__(self, driver):
+        self.driver = driver
+        table = 'HA_Chassis_Group'
+        events = (self.ROW_UPDATE,)
+        super().__init__(events, table, None)
+        self.event_name = 'HAChassisGroupRouterEvent'
+
+    def match_fn(self, event, row, old):
+        if (ovn_const.OVN_ROUTER_ID_EXT_ID_KEY in row.external_ids or
+                hasattr(old, 'ha_chassis')):
+            # "HA_Chassis_Group" has been assigned to a router or there are
+            # changes in the "ha_chassis" list.
+            return True
+        return False
+
+    def run(self, event, row, old):
+        router_id = row.external_ids[ovn_const.OVN_ROUTER_ID_EXT_ID_KEY]
+        router_name = utils.ovn_name(router_id)
+        if not row.ha_chassis:
+            # No GW chassis are present in the environment.
+            self.driver.nb_ovn.db_remove(
+                'Logical_Router', router_name, 'options', 'chassis',
+                if_exists=True).execute(check_error=True)
+            LOG.info('Router %s is not pinned to any gateway chassis',
+                     router_id)
+            return
+
+        try:
+            highest_prio_hc = max(row.ha_chassis, key=lambda hc: hc.priority)
+        except ValueError:
+            highest_prio_hc = None
+
+        if highest_prio_hc:
+            options = {'chassis': highest_prio_hc.chassis_name}
+            self.driver.nb_ovn.db_set(
+                'Logical_Router', router_name, ('options', options)).execute(
+                check_error=True)
+
+
 class OvnDbNotifyHandler(row_event.RowEventHandler):
     def __init__(self, driver):
         self.driver = driver
@@ -769,12 +874,18 @@ class OvnNbIdl(OvnIdlDistributedLock):
         self._lsp_update_up_event = LogicalSwitchPortUpdateUpEvent(driver)
         self._lsp_update_down_event = LogicalSwitchPortUpdateDownEvent(driver)
         self._lsp_create_event = LogicalSwitchPortCreateEvent(driver)
+        self._lsp_lrp_event = (
+            LogicalSwitchPortUpdateLogicalRouterPortEvent(driver))
         self._fip_create_delete_event = FIPAddDeleteEvent(driver)
+        self._ha_chassis_group_event = HAChassisGroupRouterEvent(driver)
 
         self.notify_handler.watch_events([self._lsp_create_event,
                                           self._lsp_update_up_event,
                                           self._lsp_update_down_event,
-                                          self._fip_create_delete_event])
+                                          self._fip_create_delete_event,
+                                          self._lsp_lrp_event,
+                                          self._ha_chassis_group_event,
+                                          ])
 
     @classmethod
     def from_server(cls, connection_string, helper, driver):
