@@ -52,14 +52,12 @@ _RESOURCE_FOREIGN_KEYS = {
 }
 
 # TODO(slaweq): Remove overriding the default value of config options
-# 'policy_file', 'enforce_scope', and 'enforce_new_defaults' once
-# oslo_policy change their default value to what is overridden here.
+# 'policy_file' once oslo_policy change its default value to what
+# is overridden here.
 DEFAULT_POLICY_FILE = 'policy.yaml'
 opts.set_defaults(
     cfg.CONF,
-    DEFAULT_POLICY_FILE,
-    enforce_scope=True,
-    enforce_new_defaults=True)
+    DEFAULT_POLICY_FILE)
 
 
 def reset():
