@@ -15,7 +15,7 @@
 
 import inspect
 import os
-import random
+import secrets
 
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
@@ -24,6 +24,7 @@ from neutron_lib import context
 from neutron_lib.db import api as session
 from neutron_lib.plugins import directory
 from neutron_lib import rpc as n_rpc
+from neutron_lib import worker as base_worker
 from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -34,11 +35,14 @@ from oslo_utils import excutils
 from oslo_utils import importutils
 import psutil
 
+from neutron._i18n import _
+from neutron.api import wsgi
 from neutron.common import config
 from neutron.common import profiler
 from neutron.conf import service
+from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import worker as \
+    ovn_worker
 from neutron import worker as neutron_worker
-from neutron import wsgi
 
 
 service.register_service_opts(service.SERVICE_OPTS)
@@ -100,7 +104,8 @@ class RpcWorker(neutron_worker.NeutronBaseWorker):
 
     def __init__(self, plugins, worker_process_count=1):
         super(RpcWorker, self).__init__(
-            worker_process_count=worker_process_count
+            worker_process_count=worker_process_count,
+            desc=self.desc,
         )
 
         self._plugins = plugins
@@ -158,8 +163,7 @@ def _get_worker_count():
     # a steady-state bloat of around 2GB.
     mem = psutil.virtual_memory()
     mem_workers = int(mem.total / (2 * 1024 * 1024 * 1024))
-    if mem_workers < num_workers:
-        num_workers = mem_workers
+    num_workers = min(num_workers, mem_workers)
 
     # And just in case, always at least one.
     if num_workers <= 0:
@@ -226,15 +230,26 @@ def _get_plugins_workers():
     ]
 
 
+def _get_ovn_maintenance_worker():
+    for worker in _get_plugins_workers():
+        if isinstance(worker, ovn_worker.MaintenanceWorker):
+            return worker
+
+
 class AllServicesNeutronWorker(neutron_worker.NeutronBaseWorker):
     def __init__(self, services, worker_process_count=1):
         super(AllServicesNeutronWorker, self).__init__(worker_process_count)
         self._services = services
+        for srv in self._services:
+            self._check_base_worker_service(srv)
         self._launcher = common_service.Launcher(cfg.CONF,
                                                  restart_method='mutate')
 
     def start(self):
         for srv in self._services:
+            # Unset the 'set_proctitle' flag to prevent each service to
+            # re-write the process title already defined and set by this class.
+            srv.set_proctitle = 'off'
             self._launcher.launch_service(srv)
         super(AllServicesNeutronWorker, self).start(desc="services worker")
 
@@ -247,6 +262,13 @@ class AllServicesNeutronWorker(neutron_worker.NeutronBaseWorker):
     def reset(self):
         self._launcher.restart()
 
+    @staticmethod
+    def _check_base_worker_service(srv):
+        if not isinstance(srv, base_worker.BaseWorker):
+            raise TypeError(
+                _('Service %(srv)s must an instance of %(base)s!)') %
+                {'srv': srv, 'base': base_worker.BaseWorker})
+
 
 def _start_workers(workers, neutron_api=None):
     process_workers = [
@@ -304,17 +326,35 @@ def start_all_workers(neutron_api=None):
 
 def start_rpc_workers():
     rpc_workers = _get_rpc_workers()
-    LOG.debug('using launcher for rpc, workers=%s', cfg.CONF.rpc_workers)
+    LOG.debug('Using launcher for rpc, workers=%s (configured rpc_workers=%s)',
+              len(rpc_workers), cfg.CONF.rpc_workers)
     launcher = _start_workers(rpc_workers)
     registry.publish(resources.PROCESS, events.AFTER_SPAWN, None)
     return launcher
 
 
+def start_periodic_workers():
+    periodic_workers = _get_plugins_workers()
+    thread_workers = [worker for worker in periodic_workers
+                      if worker.worker_process_count < 1]
+    launcher = _start_workers(thread_workers)
+    registry.publish(resources.PROCESS, events.AFTER_SPAWN, None)
+    return launcher
+
+
 def start_plugins_workers():
     plugins_workers = _get_plugins_workers()
     return _start_workers(plugins_workers)
 
 
+def start_ovn_maintenance_worker():
+    ovn_maintenance_worker = _get_ovn_maintenance_worker()
+    if not ovn_maintenance_worker:
+        return
+
+    return _start_workers([ovn_maintenance_worker])
+
+
 def _get_api_workers():
     workers = cfg.CONF.api_workers
     if workers is None:
@@ -346,9 +386,9 @@ class Service(n_rpc.Service):
     on topic. It also periodically runs tasks on the manager.
     """
 
-    def __init__(self, host, binary, topic, manager, report_interval=None,
-                 periodic_interval=None, periodic_fuzzy_delay=None,
-                 *args, **kwargs):
+    def __init__(self, host, binary, topic, manager, *args,
+                 report_interval=None, periodic_interval=None,
+                 periodic_fuzzy_delay=None, **kwargs):
 
         self.binary = binary
         self.manager_class_name = manager
@@ -373,7 +413,8 @@ class Service(n_rpc.Service):
 
         if self.periodic_interval:
             if self.periodic_fuzzy_delay:
-                initial_delay = random.randint(0, self.periodic_fuzzy_delay)
+                initial_delay = secrets.SystemRandom().randint(
+                    0, self.periodic_fuzzy_delay)
             else:
                 initial_delay = None
 
