@@ -250,18 +250,7 @@ class OVNL3RouterPlugin(service_base.ServicePluginBase,
                 port = self._plugin.update_port(
                     context, port['id'],
                     {'port': {portbindings.HOST_ID: host}})
-                # Updates OVN NB database with hostname for lsp router
-                # gateway port
-                with self._nb_ovn.transaction(check_error=True) as txn:
-                    ext_ids = (
-                        "external_ids",
-                        {ovn_const.OVN_HOST_ID_EXT_ID_KEY: host},
-                    )
-                    txn.add(
-                        self._nb_ovn.db_set(
-                            "Logical_Switch_Port", port["id"], ext_ids
-                        )
-                    )
+
             if port['status'] != status:
                 self._plugin.update_port_status(context, port['id'], status)
 
@@ -380,17 +369,6 @@ class OVNL3RouterPlugin(service_base.ServicePluginBase,
             reason = _("Router port must have at least one IP.")
             raise n_exc.ServicePortInUse(port_id=original['id'], reason=reason)
 
-        if (event == events.AFTER_UPDATE and
-                utils.is_lsp_router_port(current) and
-                utils.is_ovn_provider_router(
-                    l3plugin.get_router(context, current['device_id']))):
-            # We call the update_router port with if_exists, because neutron,
-            # internally creates the port, and then calls update, which will
-            # trigger this callback even before we had the chance to create
-            # the OVN NB DB side
-            l3plugin._ovn_client.update_router_port(context,
-                                                    current, if_exists=True)
-
     def get_router_availability_zones(self, router):
         lr = self._nb_ovn.get_lrouter(router['id'])
         if not lr:
@@ -417,3 +395,6 @@ class OVNL3RouterPlugin(service_base.ServicePluginBase,
     @resource_extend.extends([l3_apidef.ROUTERS])
     def add_flavor_id(router_res, router_db):
         router_res['flavor_id'] = router_db['flavor_id']
+
+    def update_router_gw_ports(self, context, network, subnet):
+        self._update_router_gateway_ports(context, network, subnet)
