@@ -266,9 +266,9 @@ class ClientFixture(fixtures.Fixture):
 
         return policy['policy']
 
-    def create_bandwidth_limit_rule(self, tenant_id, qos_policy_id, limit=None,
+    def create_bandwidth_limit_rule(self, qos_policy_id, limit=None,
                                     burst=None, direction=None):
-        rule = {'tenant_id': tenant_id}
+        rule = {}
         if limit:
             rule['max_kbps'] = limit
         if burst:
@@ -285,10 +285,9 @@ class ClientFixture(fixtures.Fixture):
 
         return rule['bandwidth_limit_rule']
 
-    def create_packet_rate_limit_rule(
-            self, project_id, qos_policy_id, limit=None,
-            burst=None, direction=None):
-        rule = {'project_id': project_id}
+    def create_packet_rate_limit_rule(self, qos_policy_id, limit=None,
+                                      burst=None, direction=None):
+        rule = {}
         if limit:
             rule['max_kpps'] = limit
         if burst:
@@ -306,10 +305,9 @@ class ClientFixture(fixtures.Fixture):
 
         return rule['packet_rate_limit_rule']
 
-    def create_minimum_bandwidth_rule(self, tenant_id, qos_policy_id,
-                                      min_bw, direction=None):
-        rule = {'tenant_id': tenant_id,
-                'min_kbps': min_bw}
+    def create_minimum_bandwidth_rule(self, qos_policy_id, min_bw,
+                                      direction=None):
+        rule = {'min_kbps': min_bw}
         if direction:
             rule['direction'] = direction
         rule = self.client.create_minimum_bandwidth_rule(
@@ -322,8 +320,8 @@ class ClientFixture(fixtures.Fixture):
 
         return rule['minimum_bandwidth_rule']
 
-    def create_dscp_marking_rule(self, tenant_id, qos_policy_id, dscp_mark=0):
-        rule = {'tenant_id': tenant_id}
+    def create_dscp_marking_rule(self, qos_policy_id, dscp_mark=0):
+        rule = {}
         if dscp_mark:
             rule['dscp_mark'] = dscp_mark
         rule = self.client.create_dscp_marking_rule(
@@ -444,3 +442,10 @@ class ClientFixture(fixtures.Fixture):
 
     def update_quota(self, project_id, tracked_resource, quota):
         self._update_resource('quota', project_id, {tracked_resource: quota})
+
+    def add_gateway_router(self, router_id, network_id):
+        self.client.add_gateway_router(
+            router_id,
+            {'network_id': network_id})
+        self.addCleanup(
+            self.client.remove_gateway_router, router_id)
