@@ -137,6 +137,11 @@ class L3AgentTestFramework(base.BaseSudoTestCase):
         conf.set_override('host', host)
         conf.set_override('agent_mode', agent_mode)
 
+        # NOTE(slaweq): iptables_manager module checks this option directly in
+        # the cfg.CONF, not in agent.conf parameter so it has to be override
+        # directly in the cfg.CONF module too
+        cfg.CONF.set_override('debug_iptables_rules', True, group='AGENT')
+
         return conf
 
     def _get_agent_ovs_integration_bridge(self, agent):
@@ -405,6 +410,7 @@ class L3AgentTestFramework(base.BaseSudoTestCase):
                 timeout=15)
         return return_copy
 
+    @test_base.unstable_test("bug 1961740")
     def manage_router(self, agent, router):
         self.addCleanup(agent._safe_router_removed, router['id'])
         with mock.patch.object(dvr_local_router.DvrLocalRouter,
