@@ -20,7 +20,6 @@ import os
 import shutil
 from unittest import mock
 import warnings
-import weakref
 
 import fixtures
 from neutron_lib.plugins import constants
@@ -33,6 +32,7 @@ from ovsdbapp.backend.ovs_idl import idlutils
 
 from neutron.agent.linux import utils
 from neutron.api import extensions as exts
+from neutron.api import wsgi
 from neutron.common import utils as n_utils
 from neutron.conf.agent import common as config
 from neutron.conf.agent import ovs_conf
@@ -48,14 +48,12 @@ from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb.extensions import \
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import worker
 from neutron.plugins.ml2.drivers import type_geneve  # noqa
 from neutron import service  # noqa
-from neutron.services.logapi.drivers.ovn import driver as log_driver
 from neutron.tests import base
 from neutron.tests.common import base as common_base
 from neutron.tests.common import helpers
 from neutron.tests.functional.resources import process
 from neutron.tests.unit.extensions import test_securitygroup
 from neutron.tests.unit.plugins.ml2 import test_plugin
-import neutron.wsgi
 
 LOG = log.getLogger(__name__)
 
@@ -172,7 +170,6 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         self.addCleanup(exts.PluginAwareExtensionManager.clear_instance)
         self.ovsdb_server_mgr = None
         self._service_plugins = service_plugins
-        log_driver.DRIVER = None
         super(TestOVNFunctionalBase, self).setUp()
         self.test_log_dir = os.path.join(DEFAULT_LOG_DIR, self.id())
         base.setup_test_logging(
@@ -195,11 +192,6 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
                 self.mech_driver.log_driver)
         self.mech_driver.log_driver.plugin_driver = self.mech_driver
         self.mech_driver.log_driver._log_plugin_property = None
-        for driver in self.log_plugin.driver_manager.drivers:
-            if driver.name == "ovn":
-                self.ovn_log_driver = driver
-        if not hasattr(self, 'ovn_log_driver'):
-            self.ovn_log_driver = log_driver.OVNDriver()
         self.ovn_northd_mgr = None
         self.maintenance_worker = maintenance_worker
         mock.patch(
@@ -219,8 +211,7 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
                 test_securitygroup.RULES_TEMPLATE_FOR_DEFAULT_SG)).start()
 
     def _reset_agent_cache_singleton(self):
-        neutron_agent.AgentCache._singleton_instances = (
-            weakref.WeakValueDictionary())
+        neutron_agent.AgentCache._instance = None
 
     def _reset_ovn_client_placement_extension(self):
         ovn_client_placement.OVNClientPlacementExtension._instance = None
@@ -338,7 +329,7 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
             trigger_cls.trigger.__self__.__class__ = worker.MaintenanceWorker
             cfg.CONF.set_override('neutron_sync_mode', 'off', 'ovn')
         else:
-            trigger_cls.trigger.__self__.__class__ = neutron.wsgi.WorkerService
+            trigger_cls.trigger.__self__.__class__ = wsgi.WorkerService
 
         self.addCleanup(self.stop)
         # NOTE(ralonsoh): do not access to the DB at exit when the SQL
@@ -461,8 +452,8 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
             self.sb_api.db_destroy(
                 'Chassis_Private', chassis).execute(check_error=True)
         except idlutils.RowNotFound:
-            # NOTE(ykarel ): ovsdbapp >= 2.6.1 handles Chassis_Private
+            # NOTE(ykarel ): ovsdbapp >= 2.7.0 handles Chassis_Private
             # record delete with chassis
             # try/except can be dropped when neutron requirements.txt
-            # include ovsdbapp>=2.6.1
+            # include ovsdbapp>=2.7.0
             pass
