@@ -28,6 +28,7 @@ from ovsdbapp.tests.functional import base
 from ovsdbapp.tests import utils
 
 from neutron.common.ovn import constants as ovn_const
+from neutron.common.ovn import utils as ovn_utils
 from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb \
     import impl_idl_ovn as impl
@@ -131,10 +132,10 @@ class TestSbApi(BaseOvnIdlTest):
         self.assertTrue(row_event.wait())
         return port.result, row_event.row
 
-    def test_get_metadata_port_network(self):
+    def test_get_metadata_port(self):
         chassis, switch = self._add_switch(self.data['chassis'][0]['name'])
         port, binding = self._add_port_to_switch(switch)
-        result = self.api.get_metadata_port_network(str(binding.datapath.uuid))
+        result = self.api.get_metadata_port(str(binding.datapath.uuid))
         self.assertEqual(binding, result)
         self.assertEqual(binding.datapath.external_ids['logical-switch'],
                          str(switch.uuid))
@@ -142,12 +143,12 @@ class TestSbApi(BaseOvnIdlTest):
             port.external_ids[ovn_const.OVN_DEVICE_OWNER_EXT_ID_KEY],
             constants.DEVICE_OWNER_DISTRIBUTED)
 
-    def test_get_metadata_port_network_other_non_metadata_port(self):
+    def test_get_metadata_port_other_non_metadata_port(self):
         chassis, switch = self._add_switch(self.data['chassis'][0]['name'])
         port, binding = self._add_port_to_switch(switch)
         port_lbhm, binding_port_lbhm = self._add_port_to_switch(
             switch, device_owner=ovn_const.OVN_LB_HM_PORT_DISTRIBUTED)
-        result = self.api.get_metadata_port_network(str(binding.datapath.uuid))
+        result = self.api.get_metadata_port(str(binding.datapath.uuid))
         self.assertEqual(binding, result)
         self.assertEqual(binding.datapath.external_ids['logical-switch'],
                          str(switch.uuid))
@@ -158,9 +159,9 @@ class TestSbApi(BaseOvnIdlTest):
             port_lbhm.external_ids[ovn_const.OVN_DEVICE_OWNER_EXT_ID_KEY],
             ovn_const.OVN_LB_HM_PORT_DISTRIBUTED)
 
-    def test_get_metadata_port_network_missing(self):
+    def test_get_metadata_port_missing(self):
         val = str(uuid.uuid4())
-        self.assertIsNone(self.api.get_metadata_port_network(val))
+        self.assertIsNone(self.api.get_metadata_port(val))
 
     def _create_bound_port_with_ip(self, mac, ipaddr):
         chassis, switch = self._add_switch(
@@ -590,6 +591,110 @@ class TestNbApi(BaseOvnIdlTest):
                 "BFD",
                 bfd_uuid)
 
+    def test_set_lsp_ha_chassis_group(self):
+        with self.nbapi.transaction(check_error=True) as txn:
+            ls_name = uuidutils.generate_uuid()
+            lsp_name = uuidutils.generate_uuid()
+            hcg_name = uuidutils.generate_uuid()
+            txn.add(self.nbapi.ls_add(ls_name))
+            txn.add(self.nbapi.lsp_add(ls_name, lsp_name))
+
+        with self.nbapi.transaction(check_error=True) as txn:
+            hcg = self.nbapi.ha_chassis_group_add(hcg_name)
+            txn.add(hcg)
+            lsp = self.nbapi.lookup('Logical_Switch_Port', lsp_name)
+            txn.add(self.nbapi.set_lswitch_port(lsp_name,
+                                                ha_chassis_group=hcg))
+
+        lsp = self.nbapi.lookup('Logical_Switch_Port', lsp_name)
+        self.assertEqual(hcg.result.uuid, lsp.ha_chassis_group[0].uuid)
+
+    def test_delete_lrouter(self):
+        router_name = ovn_utils.ovn_name(uuidutils.generate_uuid())
+        with self.nbapi.transaction(check_error=True) as txn:
+            txn.add(self.nbapi.lr_add(router_name))
+            txn.add(self.nbapi.ha_chassis_group_add(router_name))
+
+        r = self.nbapi.lookup('Logical_Router', router_name)
+        self.assertEqual(router_name, r.name)
+        hcg = self.nbapi.lookup('HA_Chassis_Group', router_name)
+        self.assertEqual(router_name, hcg.name)
+
+        self.nbapi.lr_del(router_name).execute(check_error=True)
+        self.assertIsNone(
+            self.nbapi.lookup('Logical_Router', router_name, default=None))
+        self.assertIsNone(
+            self.nbapi.lookup('HA_Chassis_Group', router_name, default=None))
+
+    def _assert_routes_exist(self, lr_name, expected_count):
+        lr = self.nbapi.lookup('Logical_Router', lr_name)
+        actual_count = len(lr.static_routes)
+        self.assertEqual(actual_count, expected_count,
+                         f"Expected {expected_count} routes, "
+                         f"found {actual_count}.")
+
+    def test_del_static_routes(self):
+        lr_name = ovn_utils.ovn_name(uuidutils.generate_uuid())
+        routes = [('0.0.0.0/0', '192.0.2.1'), ('10.0.0.0/24', '192.0.3.1')]
+
+        with self.nbapi.transaction(check_error=True) as txn:
+            txn.add(self.nbapi.lr_add(lr_name))
+            for ip_prefix, nexthop in routes:
+                txn.add(self.nbapi.add_static_route(lr_name,
+                                                    ip_prefix=ip_prefix,
+                                                    nexthop=nexthop))
+
+        self._assert_routes_exist(lr_name, 2)
+
+        with self.nbapi.transaction(check_error=True) as txn:
+            txn.add(self.nbapi.delete_static_routes(lr_name, routes))
+
+        self._assert_routes_exist(lr_name, 0)
+
+    def test_del_no_static_routes(self):
+        lr_name = ovn_utils.ovn_name(uuidutils.generate_uuid())
+        routes = []
+
+        with self.nbapi.transaction(check_error=True) as txn:
+            txn.add(self.nbapi.lr_add(lr_name))
+
+        self._assert_routes_exist(lr_name, 0)
+
+        with self.nbapi.transaction(check_error=True) as txn:
+            txn.add(self.nbapi.delete_static_routes(lr_name, routes))
+
+        self._assert_routes_exist(lr_name, 0)
+
+    def test_modify_static_route_external_ids(self):
+        lr_name = 'router_with_static_routes_and_external_ids'
+        columns = {
+            'bfd': [],
+            'external_ids': {'fake_eid_key': 'fake_eid_value'},
+            'ip_prefix': '0.0.0.0/0',
+            'nexthop': '192.0.2.1',
+            'options': {'fake_option_key': 'fake_option_value'},
+            'output_port': [],
+            'policy': ['dst-ip'],
+            'route_table': '',
+        }
+        with self.nbapi.transaction(check_error=True) as txn:
+            r = self._add_static_route(txn, lr_name, '', **columns)
+
+        # modify the external_ids
+        new_ids = {'external_ids': {'fake_eid_key': 'fake_eid_value',
+                                    ovn_const.OVN_LRSR_EXT_ID_KEY: 'true'}}
+
+        with self.nbapi.transaction(check_error=True) as txn:
+            txn.add(self.nbapi.set_static_route(r.result.static_routes[0],
+                                                **new_ids))
+
+        lr = self.nbapi.lookup('Logical_Router', lr_name)
+
+        external_ids = {'fake_eid_key': 'fake_eid_value',
+                        ovn_const.OVN_LRSR_EXT_ID_KEY: 'true'}
+
+        self.assertEqual(external_ids, lr.static_routes[0].external_ids)
+
 
 class TestIgnoreConnectionTimeout(BaseOvnIdlTest):
     @classmethod
