@@ -16,6 +16,7 @@
 from unittest import mock
 
 from oslo_config import cfg
+from oslo_utils import strutils
 
 from futurist import periodics
 from neutron_lib.api.definitions import external_net as extnet_apidef
@@ -68,12 +69,17 @@ class _TestMaintenanceHelper(base.TestOVNFunctionalBase):
                     ovn_const.OVN_NETWORK_NAME_EXT_ID_KEY) == name):
                 return row
 
-    def _create_network(self, name, external=False, provider=None):
+    def _create_network(self, name, external=False, provider=None,
+                        net_type=None):
         data = {'network': {'name': name,
                             extnet_apidef.EXTERNAL: external}}
+        if net_type:
+            data['network'][provnet_apidef.NETWORK_TYPE] = net_type
         if provider:
-            data['network'][provnet_apidef.NETWORK_TYPE] = 'flat'
+            net_type = net_type or 'flat'
+            data['network'][provnet_apidef.NETWORK_TYPE] = net_type
             data['network'][provnet_apidef.PHYSICAL_NETWORK] = provider
+
         req = self.new_create_request('networks', data, self.fmt,
                                       as_admin=True)
         res = req.get_response(self.api)
@@ -380,8 +386,7 @@ class TestMaintenance(_TestMaintenanceHelper):
         # Assert the revision number no longer exists
         self.assertIsNone(db_rev.get_revision_row(
             self.context,
-            neutron_obj['id'],
-            resource_type=ovn_const.TYPE_PORTS))
+            neutron_obj['id']))
 
     def test_subnet_global_dhcp4_opts(self):
         obj_name = 'globaltestsubnet'
@@ -1064,63 +1069,62 @@ class TestMaintenance(_TestMaintenanceHelper):
         lsp = self.nb_api.lookup('Logical_Switch_Port', p1['id'])
         self.assertEqual(hcg_uuid, lsp.ha_chassis_group[0].uuid)
 
-    def test_remove_duplicated_chassis_registers(self):
-        hostnames = ['host1', 'host2']
-        for hostname in hostnames:
-            for _ in range(3):
-                self.add_fake_chassis(hostname)
+    def _test_check_provider_distributed_ports(
+            self, is_distributed_fip, net_type, expected_value=None):
+        cfg.CONF.set_override(
+            'enable_distributed_floating_ip', is_distributed_fip, group='ovn')
+        net_args = {'net_type': net_type}
+        if net_type == n_const.TYPE_FLAT:
+            net_args['provider'] = 'datacentre'
+        net = self._create_network(
+            'net_distributed_ports_test', **net_args)
+        subnet = self._create_subnet('subnet_distributed_ports_test',
+                                     net['id'])
+        router = self._create_router('router_distributed_ports_test')
+        self._add_router_interface(router['id'], subnet['id'])
 
-        chassis = self.sb_api.chassis_list().execute(check_error=True)
-        self.assertEqual(6, len(chassis))
-        # Make the chassis private timestamp different
-        for idx, ch in enumerate(chassis):
-            self.sb_api.db_set('Chassis_Private', ch.name,
-                               ('nb_cfg_timestamp', idx)).execute()
+        # Lets make sure that reside-on-chassis-redirect is not set for the LRP
+        lr = self.nb_api.lookup('Logical_Router',
+                                utils.ovn_name(router['id']))
+        lrp = lr.ports[0]
+        self.nb_api.db_remove(
+            'Logical_Router_Port',
+            lrp.name,
+            'options',
+            ovn_const.LRP_OPTIONS_RESIDE_REDIR_CH
+        ).execute()
 
-        ch_private_dict = {}  # host: [ch_private1, ch_private2, ...]
-        for hostname in hostnames:
-            ch_private_list = []
-            for ch in (ch for ch in chassis if ch.hostname == hostname):
-                ch_private = self.sb_api.lookup('Chassis_Private', ch.name,
-                                                default=None)
-                if ch_private:
-                    # One of the "Chassis_Private" has been deleted on purpose
-                    # in this test.
-                    ch_private_list.append(ch_private)
-            ch_private_list.sort(key=lambda x: x.nb_cfg_timestamp,
-                                 reverse=True)
-            ch_private_dict[hostname] = ch_private_list
+        self.assertRaises(periodics.NeverAgain,
+                          self.maint.check_provider_distributed_ports)
 
-        self.maint.remove_duplicated_chassis_registers()
-        chassis_result = self.sb_api.chassis_list().execute(check_error=True)
-        self.assertEqual(2, len(chassis_result))
-        for ch in chassis_result:
-            self.assertIn(ch.hostname, hostnames)
-            hostnames.remove(ch.hostname)
-            # From ch_private_dict[ch.hostname], we retrieve the first
-            # "Chassis_Private" register because these are ordered by
-            # timestamp. The newer one (bigger timestamp) should remain in the
-            # system.
-            ch_expected = ch_private_dict[ch.hostname][0].chassis[0]
-            self.assertEqual(ch_expected.name, ch.name)
+        lrp = self.nb_api.lookup('Logical_Router_Port', lrp.name)
+        if net_type in [n_const.TYPE_VLAN, n_const.TYPE_FLAT]:
+            self.assertEqual(
+                expected_value,
+                strutils.bool_from_string(
+                    lrp.options[ovn_const.LRP_OPTIONS_RESIDE_REDIR_CH]))
+        else:
+            self.assertNotIn(
+                ovn_const.LRP_OPTIONS_RESIDE_REDIR_CH,
+                lrp.options)
 
-    def test_remove_duplicated_chassis_registers_no_ch_private_register(self):
-        for _ in range(2):
-            self.add_fake_chassis('host1')
+    def test_check_provider_distributed_ports_dvr_vlan_net(self):
+        self._test_check_provider_distributed_ports(True, 'vlan', False)
 
-        chassis = self.sb_api.chassis_list().execute(check_error=True)
-        self.assertEqual(2, len(chassis))
-        # Make the chassis private timestamp different
-        # Delete on of the "Chassis_Private" registers.
-        self.sb_api.db_destroy('Chassis_Private', chassis[0].name).execute()
-        self.sb_api.db_set('Chassis_Private', chassis[1].name,
-                           ('nb_cfg_timestamp', 1)).execute()
+    def test_check_provider_distributed_ports_non_dvr_vlan_net(self):
+        self._test_check_provider_distributed_ports(False, 'vlan', True)
 
-        self.maint.remove_duplicated_chassis_registers()
-        chassis_result = self.sb_api.chassis_list().execute(check_error=True)
-        # Both "Chassis" registers are still in the DB because one
-        # "Chassis_Private" register was missing.
-        self.assertEqual(2, len(chassis_result))
+    def test_check_provider_distributed_ports_dvr_flat_net(self):
+        self._test_check_provider_distributed_ports(True, 'flat', False)
+
+    def test_check_provider_distributed_ports_non_dvr_flat_net(self):
+        self._test_check_provider_distributed_ports(False, 'flat', True)
+
+    def test_check_provider_distributed_ports_dvr_geneve_net(self):
+        self._test_check_provider_distributed_ports(True, 'geneve')
+
+    def test_check_provider_distributed_ports_non_dvr_geneve_net(self):
+        self._test_check_provider_distributed_ports(False, 'geneve')
 
     def test_configure_nb_global(self):
         def options_intersect(options1, options2):
@@ -1270,53 +1274,126 @@ class TestMaintenance(_TestMaintenanceHelper):
         lr = self.nb_api.lookup('Logical_Router', utils.ovn_name(router['id']))
         self.assertEqual([], lr.ports[0].gateway_chassis)
 
-    def _get_nb_global_external_ids(self):
-        return self.nb_api.db_get(
-            'NB_Global', '.', 'external_ids').execute(check_error=True)
+    def test_set_network_type(self):
+        net1 = self._create_network(uuidutils.generate_uuid())
+        ls_name = utils.ovn_name(net1['id'])
+        self.nb_api.db_remove(
+            'Logical_Switch', ls_name, 'external_ids',
+            ovn_const.OVN_NETTYPE_EXT_ID_KEY).execute(check_error=True)
+        ls = self.nb_api.lookup('Logical_Switch', ls_name)
+        self.assertIsNone(ls.external_ids.get(
+            ovn_const.OVN_NETTYPE_EXT_ID_KEY))
 
-    def test_set_fip_distributed_flag(self):
-        ovn_config.cfg.CONF.set_override(
-            'enable_distributed_floating_ip', True, 'ovn')
-        nb_global_ext_id = self._get_nb_global_external_ids()
-        self.assertNotIn(ovn_const.OVN_FIP_DISTRIBUTED_KEY, nb_global_ext_id)
+        self.assertRaises(periodics.NeverAgain, self.maint.set_network_type)
+        ls = self.nb_api.lookup('Logical_Switch', ls_name)
+        self.assertEqual(net1[provnet_apidef.NETWORK_TYPE],
+                         ls.external_ids.get(ovn_const.OVN_NETTYPE_EXT_ID_KEY))
 
+    def test_check_network_broadcast_arps_to_all_routers(self):
+        net = self._create_network('net', external=True)
+        ls = self.nb_api.get_lswitch(utils.ovn_name(net['id']))
+
+        self.assertEqual(
+            'true',
+            ls.other_config.get(ovn_const.LS_OPTIONS_BROADCAST_ARPS_ROUTERS))
+
+        # Change the value of the configuration
+        cfg.CONF.set_override(
+            'broadcast_arps_to_all_routers', False, group='ovn')
+
+        # Call the maintenance task and check that the value has been
+        # updated in the Logical Switch
         self.assertRaises(
-            periodics.NeverAgain, self.maint.set_fip_distributed_flag)
+            periodics.NeverAgain,
+            self.maint.check_network_broadcast_arps_to_all_routers)
+
+        ls = self.nb_api.get_lswitch(utils.ovn_name(net['id']))
 
-        nb_global_ext_id = self._get_nb_global_external_ids()
         self.assertEqual(
-            "True", nb_global_ext_id[ovn_const.OVN_FIP_DISTRIBUTED_KEY])
+            'false',
+            ls.other_config.get(ovn_const.LS_OPTIONS_BROADCAST_ARPS_ROUTERS))
 
-    def _test_set_fip_distributed_flag_change(
-            self, original_value, config_value):
-        ovn_config.cfg.CONF.set_override(
-            'enable_distributed_floating_ip', config_value, 'ovn')
-        self.nb_api.db_set(
-            'NB_Global', '.', external_ids={
-                ovn_const.OVN_FIP_DISTRIBUTED_KEY: str(original_value)}
-        ).execute(check_error=True)
-        nb_global_ext_id = self._get_nb_global_external_ids()
-        self.assertEqual(
-            str(original_value),
-            nb_global_ext_id[ovn_const.OVN_FIP_DISTRIBUTED_KEY])
+    def test_static_routes_with_external_ids(self):
+        ext_net = self._create_network('ext_networktest', external=True)
+        ext_subnet = self._create_subnet(
+            'ext_subnettest',
+            ext_net['id'],
+            **{'cidr': '100.0.0.0/24',
+               'gateway_ip': '100.0.0.254',
+               'allocation_pools': [
+                   {'start': '100.0.0.2', 'end': '100.0.0.253'}],
+               'enable_dhcp': False})
+        net1 = self._create_network('network1test', external=False)
+        subnet1 = self._create_subnet('subnet1test', net1['id'])
+        external_gateway_info = {
+            'enable_snat': True,
+            'network_id': ext_net['id'],
+            'external_fixed_ips': [
+                {'ip_address': '100.0.0.2', 'subnet_id': ext_subnet['id']}]}
+        router = self._create_router(
+            'routertest', external_gateway_info=external_gateway_info)
+        self._add_router_interface(router['id'], subnet1['id'])
 
-        self.assertRaises(
-            periodics.NeverAgain, self.maint.set_fip_distributed_flag)
+        # Create static routes via Neutron
+        with mock.patch.object(self.nb_api,
+                'add_static_route', columns=None):
+            self.l3_plugin.update_router(
+                self.context, router['id'],
+                {'router': {'routes': [{'destination': '10.10.0.0/24',
+                                        'nexthop': '100.0.0.3'},
+                                       {'destination': '20.0.0.0/24',
+                                        'nexthop': '100.0.0.6'}]}})
 
-        nb_global_ext_id = self._get_nb_global_external_ids()
-        self.assertEqual(
-            str(config_value),
-            nb_global_ext_id[ovn_const.OVN_FIP_DISTRIBUTED_KEY])
+        # Create a Neutron owned static route with external_ids key
+        columns = {'external_ids': {ovn_const.OVN_LRSR_EXT_ID_KEY: 'true'}}
+        with self.nb_api.transaction(check_error=True) as txn:
+            txn.add(self.nb_api.add_static_route('neutron-' + router['id'],
+                                                 ip_prefix='10.10.0.0/24',
+                                                 nexthop='100.0.0.3',
+                                                 **columns))
 
-    def test_set_fip_distributed_flag_changed(self):
-        self._test_set_fip_distributed_flag_change(
-            original_value=False,
-            config_value=True)
+        # Create a Neutron owned static route without external_ids key
+        with self.nb_api.transaction(check_error=True) as txn:
+            txn.add(self.nb_api.add_static_route('neutron-' + router['id'],
+                                                 ip_prefix='20.0.0.0/24',
+                                                 nexthop='100.0.0.6'))
 
-    def test_set_fip_distributed_flag_unchanged(self):
-        self._test_set_fip_distributed_flag_change(
-            original_value=True,
-            config_value=True)
+        # Create an OVN externally managed static route without external_ids
+        with self.nb_api.transaction(check_error=True) as txn:
+            txn.add(self.nb_api.add_static_route('neutron-' + router['id'],
+                                                 ip_prefix='30.0.0.0/24',
+                                                 nexthop='100.0.0.9'))
+
+        sroutes = self.nb_api.get_all_logical_routers_static_routes()[0]
+        sroute_info = sroutes['static_routes']
+        for route in sroute_info:
+            if route.ip_prefix == '10.10.0.0/24':
+                self.assertEqual(route.external_ids,
+                    {ovn_const.OVN_LRSR_EXT_ID_KEY: 'true'})
+            if route.ip_prefix == '20.0.0.0/24':
+                self.assertEqual({}, route.external_ids)
+            if route.ip_prefix == '30.0.0.0/24':
+                self.assertEqual({}, route.external_ids)
+
+        # Call the maintenance task and check that the value has been
+        # updated in the external_ids.
+        self.assertRaises(periodics.NeverAgain,
+            self.maint.update_router_static_routes)
+
+        sroutes = self.nb_api.get_all_logical_routers_static_routes()[0]
+        sroute_info = sroutes['static_routes']
+        for route in sroute_info:
+            if route.ip_prefix == '10.10.0.0/24':
+                self.assertEqual(route.external_ids,
+                    {ovn_const.OVN_LRSR_EXT_ID_KEY: 'true'})
+            # Check if the OVN static route was updated with the Neutron key
+            if route.ip_prefix == '20.0.0.0/24':
+                self.assertEqual(route.external_ids,
+                    {ovn_const.OVN_LRSR_EXT_ID_KEY: 'true'})
+            # Check if the externally managed OVN static route remains
+            # without the Neutron key.
+            if route.ip_prefix == '30.0.0.0/24':
+                self.assertEqual({}, route.external_ids)
 
 
 class TestLogMaintenance(_TestMaintenanceHelper,
