@@ -12,11 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from neutron_lib.api.definitions import external_net
 from neutron_lib.api.definitions import provider_net
 from neutron_lib import constants
 from oslo_config import cfg
 from oslo_utils import strutils
-from sqlalchemy.dialects.mysql import dialect as mysql_dialect
 
 from neutron.common.ovn import constants as ovn_const
 from neutron.common.ovn import utils as ovn_utils
@@ -24,16 +24,13 @@ from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf as ovn_config
 from neutron.tests.functional import base
 from neutron.tests.unit.api import test_extensions
 from neutron.tests.unit.extensions import test_l3
-from neutron.tests.unit import testlib_api
 
 
-class TestOVNClient(testlib_api.MySQLTestCaseMixin,
-                    base.TestOVNFunctionalBase,
+class TestOVNClient(base.TestOVNFunctionalBase,
                     test_l3.L3NatTestCaseMixin):
 
     def setUp(self, **kwargs):
         super().setUp(**kwargs)
-        self.assertEqual(mysql_dialect.name, self.db.engine.dialect.name)
         ext_mgr = test_l3.L3TestExtensionManager()
         self.ext_api = test_extensions.setup_extensions_middleware(ext_mgr)
 
@@ -102,6 +99,40 @@ class TestOVNClient(testlib_api.MySQLTestCaseMixin,
                     # switch ports
                     ovn_client.create_port(self.context, port_data)
 
+    def test_create_router(self):
+        ch = self.add_fake_chassis('host1', enable_chassis_as_gw=True,
+                                   azs=[])
+        net_arg = {provider_net.NETWORK_TYPE: 'geneve',
+                   external_net.EXTERNAL: True}
+        with self.network('test-ovn-client', as_admin=True,
+                          arg_list=tuple(net_arg.keys()), **net_arg) as net:
+            with self.subnet(net):
+                ext_gw = {'network_id': net['network']['id']}
+                with self.router(external_gateway_info=ext_gw) as router:
+                    router_id = router['router']['id']
+                    lr = self.nb_api.lookup('Logical_Router',
+                                            ovn_utils.ovn_name(router_id))
+                    self.assertEqual(ch, lr.options['chassis'])
+                    lrp = lr.ports[0]
+                    self.assertTrue(strutils.bool_from_string(
+                        lrp.external_ids[ovn_const.OVN_ROUTER_IS_EXT_GW]))
+                    hcg = self.nb_api.lookup('HA_Chassis_Group',
+                                            ovn_utils.ovn_name(router_id))
+                    self.assertIsNotNone(hcg)
+
+                    # Remove the external GW port.
+                    self._update('routers', router_id,
+                                 {'router': {'external_gateway_info': {}}},
+                                 as_admin=True)
+                    lr = self.nb_api.lookup('Logical_Router',
+                                            ovn_utils.ovn_name(router_id))
+                    self.assertEqual([], lr.ports)
+                    self.assertNotIn('chassis', lr.options)
+                    hcg = self.nb_api.lookup('HA_Chassis_Group',
+                                             ovn_utils.ovn_name(router_id),
+                                             default=None)
+                    self.assertIsNone(hcg)
+
     def _test_router_reside_chassis_redirect(
             self, is_distributed_fip, net_type, expected_value=None):
         cfg.CONF.set_override(
@@ -149,44 +180,3 @@ class TestOVNClient(testlib_api.MySQLTestCaseMixin,
 
     def test_router_reside_chassis_redirect_non_dvr_geneve_net(self):
         self._test_router_reside_chassis_redirect(False, 'geneve')
-
-    def test_process_address_group(self):
-        def _find_address_set_for_ag():
-            as_v4 = self.nb_api.lookup(
-                'Address_Set',
-                ovn_utils.ovn_ag_addrset_name(
-                    ag['id'], 'ip' + str(constants.IP_VERSION_4)),
-                default=None)
-            as_v6 = self.nb_api.lookup(
-                'Address_Set',
-                ovn_utils.ovn_ag_addrset_name(
-                    ag['id'], 'ip' + str(constants.IP_VERSION_6)),
-                default=None)
-            return as_v4, as_v6
-
-        ovn_client = self.mech_driver._ovn_client
-        ag_args = {'project_id': 'project_1',
-                   'name': 'test_address_group',
-                   'description': 'test address group',
-                   'addresses': ['192.168.2.2/32',
-                                 '2001:db8::/32']}
-        ag = self.plugin.create_address_group(self.context,
-                                              {'address_group': ag_args})
-        self.assertIsNotNone(_find_address_set_for_ag()[0])
-        self.assertIsNotNone(_find_address_set_for_ag()[1])
-
-        # Call the create_address_group again to ensure that the create
-        # command automatically checks for existing Address_Set
-        ovn_client.create_address_group(self.context, ag)
-
-        # Update the address group
-        ag['addresses'] = ['20.0.0.1/32', '2002:db8::/32']
-        ovn_client.update_address_group(self.context, ag)
-        as_v4_new = _find_address_set_for_ag()[0]
-        as_v6_new = _find_address_set_for_ag()[1]
-        self.assertEqual(['20.0.0.1/32'], as_v4_new.addresses)
-        self.assertEqual(['2002:db8::/32'], as_v6_new.addresses)
-
-        # Delete the address group
-        ovn_client.delete_address_group(self.context, ag['id'])
-        self.assertEqual((None, None), _find_address_set_for_ag())
