@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from collections import defaultdict
 from collections import namedtuple
 
 import netaddr
@@ -22,11 +23,12 @@ from neutron_lib.api.definitions import floating_ip_port_forwarding as pf_def
 from neutron_lib.api.definitions import port_security as ps
 from neutron_lib import constants
 from neutron_lib import context
+from neutron_lib.db import api as db_api
 from neutron_lib.services.qos import constants as qos_const
+from oslo_config import cfg
 from oslo_utils import uuidutils
 from ovsdbapp.backend.ovs_idl import idlutils
 from ovsdbapp import constants as ovsdbapp_const
-from sqlalchemy.dialects.mysql import dialect as mysql_dialect
 
 from neutron.common.ovn import acl as acl_utils
 from neutron.common.ovn import constants as ovn_const
@@ -43,18 +45,16 @@ from neutron.tests.functional import base
 from neutron.tests.unit.api import test_extensions
 from neutron.tests.unit.extensions import test_extraroute
 from neutron.tests.unit.extensions import test_securitygroup
-from neutron.tests.unit import testlib_api
 
 
-class TestOvnNbSync(testlib_api.MySQLTestCaseMixin,
-                    base.TestOVNFunctionalBase):
+class TestOvnNbSync(base.TestOVNFunctionalBase):
 
     _extension_drivers = ['port_security', 'dns', 'qos', 'revision_plugin']
 
     def setUp(self, *args):
         super(TestOvnNbSync, self).setUp(maintenance_worker=True)
-        self.assertEqual(mysql_dialect.name, self.db.engine.dialect.name)
         ovn_config.cfg.CONF.set_override('dns_domain', 'ovn.test')
+        cfg.CONF.set_override('quota_security_group_rule', -1, group='QUOTAS')
         ext_mgr = test_extraroute.ExtraRouteTestExtensionManager()
         self.ext_api = test_extensions.setup_extensions_middleware(ext_mgr)
         sg_mgr = test_securitygroup.SecurityGroupTestExtensionManager()
@@ -797,14 +797,19 @@ class TestOvnNbSync(testlib_api.MySQLTestCaseMixin,
                 txn.add(self.nb_api.delete_lrouter_port(lrport,
                                                         lrouter_name, True))
 
+            columns = {'external_ids': {ovn_const.OVN_LRSR_EXT_ID_KEY: 'true'}}
             for lrouter_name, ip_prefix, nexthop in self.create_lrouter_routes:
                 txn.add(self.nb_api.add_static_route(lrouter_name,
                                                      ip_prefix=ip_prefix,
-                                                     nexthop=nexthop))
-
+                                                     nexthop=nexthop,
+                                                     **columns))
+            routers = defaultdict(list)
             for lrouter_name, ip_prefix, nexthop in self.delete_lrouter_routes:
-                txn.add(self.nb_api.delete_static_route(lrouter_name,
-                                                        ip_prefix, nexthop,
+                routers[lrouter_name].append((ip_prefix, nexthop))
+
+            for lrouter_name, routes_to_delete in routers.items():
+                txn.add(self.nb_api.delete_static_routes(lrouter_name,
+                                                        routes_to_delete,
                                                         True))
 
             for lrouter_name, nat_dict in self.create_lrouter_nats:
@@ -1754,6 +1759,56 @@ class TestOvnNbSync(testlib_api.MySQLTestCaseMixin,
         nb_synchronizer.sync_fip_qos_policies(ctx)
         self._validate_qos_records()
 
+    def _create_security_group_rule(self, sg_id, direction, tcp_port):
+        data = {'security_group_rule': {'security_group_id': sg_id,
+                                        'direction': direction,
+                                        'protocol': constants.PROTO_NAME_TCP,
+                                        'ethertype': constants.IPv4,
+                                        'port_range_min': tcp_port,
+                                        'port_range_max': tcp_port}}
+        req = self.new_create_request('security-group-rules', data, self.fmt)
+        res = req.get_response(self.api)
+        sgr = self.deserialize(self.fmt, res)
+        self.assertIn('security_group_rule', sgr)
+        return sgr['security_group_rule']['id']
+
+    def test_sync_acls(self):
+        data = {'security_group': {'name': 'sg1'}}
+        sg_req = self.new_create_request('security-groups', data)
+        res = sg_req.get_response(self.api)
+        sg = self.deserialize(self.fmt, res)['security_group']
+
+        sgr_ids = []
+        for tcp_port in range(8050, 8055):
+            sgr_ids.append(self._create_security_group_rule(
+                sg['id'], 'ingress', tcp_port))
+        for tcp_port in range(10000, 10005):
+            sgr_ids.append(self._create_security_group_rule(
+                sg['id'], 'egress', tcp_port))
+        self._validate_acls()
+
+        # Delete ACLs from the OVN DB.
+        with self.nb_api.transaction(check_error=True) as txn:
+            pg_name = utils.ovn_port_group_name(sg['id'])
+            txn.add(self.nb_api.pg_acl_del(pg_name, direction='to-lport'))
+        self._validate_acls(should_match=False)
+
+        nb_synchronizer = ovn_db_sync.OvnNbSynchronizer(
+            self.plugin, self.mech_driver.nb_ovn, self.mech_driver.sb_ovn,
+            'repair', self.mech_driver)
+        ctx = context.get_admin_context()
+        nb_synchronizer.sync_acls(ctx)
+        self._validate_acls()
+        # Delete Security Group Rules from Neutron DB.
+        for i in range(5):
+            with db_api.CONTEXT_WRITER.using(context):
+                sgr = self.plugin._get_security_group_rule(
+                    self.ctx, sgr_ids[i])
+                sgr.delete()
+        self._validate_acls(should_match=False)
+        nb_synchronizer.sync_acls(ctx)
+        self._validate_acls()
+
 
 class TestOvnSbSync(base.TestOVNFunctionalBase):
 
@@ -1763,7 +1818,6 @@ class TestOvnSbSync(base.TestOVNFunctionalBase):
             self.plugin, self.mech_driver.sb_ovn, self.mech_driver)
         self.addCleanup(self.sb_synchronizer.stop)
         self.ctx = context.get_admin_context()
-        self.host1 = uuidutils.generate_uuid()
 
     def _sync_resources(self):
         self.sb_synchronizer.sync_hostname_and_physical_networks(self.ctx)
@@ -1797,23 +1851,23 @@ class TestOvnSbSync(base.TestOVNFunctionalBase):
     def test_ovn_sb_sync_add_new_host(self):
         with self.network() as network:
             network_id = network['network']['id']
-        self.create_segment(network_id, self.physnet, 50)
-        self.add_fake_chassis(self.host1, [self.physnet])
+        self.create_segment(network_id, 'physnet1', 50)
+        self.add_fake_chassis('host1', ['physnet1'])
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
         self.assertFalse(segment_hosts)
         self._sync_resources()
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
-        self.assertEqual({self.host1}, segment_hosts)
+        self.assertEqual({'host1'}, segment_hosts)
 
     def test_ovn_sb_sync_update_existing_host(self):
         with self.network() as network:
             network_id = network['network']['id']
-        segment = self.create_segment(network_id, self.physnet, 50)
+        segment = self.create_segment(network_id, 'physnet1', 50)
         segments_db.update_segment_host_mapping(
-            self.ctx, self.host1, {segment['id']})
+            self.ctx, 'host1', {segment['id']})
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
-        self.assertEqual({self.host1}, segment_hosts)
-        self.add_fake_chassis(self.host1, [self.physnet2])
+        self.assertEqual({'host1'}, segment_hosts)
+        self.add_fake_chassis('host1', ['physnet2'])
         self._sync_resources()
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
         self.assertFalse(segment_hosts)
@@ -1821,14 +1875,13 @@ class TestOvnSbSync(base.TestOVNFunctionalBase):
     def test_ovn_sb_sync_delete_stale_host(self):
         with self.network() as network:
             network_id = network['network']['id']
-        segment = self.create_segment(network_id, self.physnet, 50)
+        segment = self.create_segment(network_id, 'physnet1', 50)
         segments_db.update_segment_host_mapping(
-            self.ctx, self.host1, {segment['id']})
-        _ = self.create_agent(self.host1,
-                              bridge_mappings={self.physnet: 'eth0'})
+            self.ctx, 'host1', {segment['id']})
+        _ = self.create_agent('host1', bridge_mappings={'physnet1': 'eth0'})
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
-        self.assertEqual({self.host1}, segment_hosts)
-        # Since there is no chassis in the sb DB, self.host1 is the stale host
+        self.assertEqual({'host1'}, segment_hosts)
+        # Since there is no chassis in the sb DB, host1 is the stale host
         # recorded in neutron DB. It should be deleted after sync.
         self._sync_resources()
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
@@ -1837,61 +1890,57 @@ class TestOvnSbSync(base.TestOVNFunctionalBase):
     def test_ovn_sb_sync_host_with_no_agent_not_deleted(self):
         with self.network() as network:
             network_id = network['network']['id']
-        segment = self.create_segment(network_id, self.physnet, 50)
+        segment = self.create_segment(network_id, 'physnet1', 50)
         segments_db.update_segment_host_mapping(
-            self.ctx, self.host1, {segment['id']})
-        _ = self.create_agent(self.host1,
-                              bridge_mappings={self.physnet: 'eth0'},
+            self.ctx, 'host1', {segment['id']})
+        _ = self.create_agent('host1', bridge_mappings={'physnet1': 'eth0'},
                               agent_type="Not OVN Agent")
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
-        self.assertEqual({self.host1}, segment_hosts)
-        # There is no chassis in the sb DB, self.host1 does not have an agent
+        self.assertEqual({'host1'}, segment_hosts)
+        # There is no chassis in the sb DB, host1 does not have an agent
         # so it is not deleted.
         self._sync_resources()
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
-        self.assertEqual({self.host1}, segment_hosts)
+        self.assertEqual({'host1'}, segment_hosts)
 
     def test_ovn_sb_sync_host_with_other_agent_type_not_deleted(self):
         with self.network() as network:
             network_id = network['network']['id']
-        segment = self.create_segment(network_id, self.physnet, 50)
+        segment = self.create_segment(network_id, 'physnet1', 50)
         segments_db.update_segment_host_mapping(
-            self.ctx, self.host1, {segment['id']})
+            self.ctx, 'host1', {segment['id']})
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
-        self.assertEqual({self.host1}, segment_hosts)
-        # There is no chassis in the sb DB, self.host1 does not have an agent
+        self.assertEqual({'host1'}, segment_hosts)
+        # There is no chassis in the sb DB, host1 does not have an agent
         # so it is not deleted.
         self._sync_resources()
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
-        self.assertEqual({self.host1}, segment_hosts)
+        self.assertEqual({'host1'}, segment_hosts)
 
     def test_ovn_sb_sync(self):
-        host2 = uuidutils.generate_uuid()
-        host3 = uuidutils.generate_uuid()
-        host4 = uuidutils.generate_uuid()
         with self.network() as network:
             network_id = network['network']['id']
-        seg1 = self.create_segment(network_id, self.physnet, 50)
-        self.create_segment(network_id, self.physnet2, 51)
+        seg1 = self.create_segment(network_id, 'physnet1', 50)
+        self.create_segment(network_id, 'physnet2', 51)
         segments_db.update_segment_host_mapping(
-            self.ctx, self.host1, {seg1['id']})
+            self.ctx, 'host1', {seg1['id']})
         segments_db.update_segment_host_mapping(
-            self.ctx, host2, {seg1['id']})
+            self.ctx, 'host2', {seg1['id']})
         segments_db.update_segment_host_mapping(
-            self.ctx, host3, {seg1['id']})
+            self.ctx, 'host3', {seg1['id']})
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
-        _ = self.create_agent(self.host1)
-        _ = self.create_agent(host2, bridge_mappings={self.physnet2: 'eth0'})
-        _ = self.create_agent(host3, bridge_mappings={self.physnet3: 'eth0'})
-        self.assertEqual({self.host1, host2, host3}, segment_hosts)
-        self.add_fake_chassis(host2, [self.physnet2])
-        self.add_fake_chassis(host3, [self.physnet3])
-        self.add_fake_chassis(host4, [self.physnet])
+        _ = self.create_agent('host1')
+        _ = self.create_agent('host2', bridge_mappings={'physnet2': 'eth0'})
+        _ = self.create_agent('host3', bridge_mappings={'physnet3': 'eth0'})
+        self.assertEqual({'host1', 'host2', 'host3'}, segment_hosts)
+        self.add_fake_chassis('host2', ['physnet2'])
+        self.add_fake_chassis('host3', ['physnet3'])
+        self.add_fake_chassis('host4', ['physnet1'])
         self._sync_resources()
         segment_hosts = segments_db.get_hosts_mapped_with_segments(self.ctx)
         # host1 should be cleared since it is not in the chassis DB. host3
         # should be cleared since there is no segment for mapping.
-        self.assertEqual({host2, host4}, segment_hosts)
+        self.assertEqual({'host2', 'host4'}, segment_hosts)
 
 
 class TestOvnNbSyncOverTcp(TestOvnNbSync):
