@@ -775,6 +775,18 @@ class TestIpAddrCommand(TestIPCmdBase):
             'global',
             None)
 
+    @mock.patch.object(priv_lib, 'add_ip_address')
+    def test_add_address_broadcast(self, add):
+        self.addr_cmd.add('192.168.45.100/32')
+        add.assert_called_once_with(
+            4,
+            '192.168.45.100',
+            32,
+            self.parent.name,
+            self.addr_cmd._parent.namespace,
+            'global',
+            '192.168.45.100')
+
     @mock.patch.object(priv_lib, 'delete_ip_address')
     def test_del_address(self, delete):
         self.addr_cmd.delete('192.168.45.100/24')
@@ -1177,6 +1189,24 @@ class TestSysctl(base.BaseTestCase):
             self.assertFalse(self.execute.called)
 
 
+class TestGetSysctl(base.BaseTestCase):
+    @mock.patch.object(ip_lib, 'IPWrapper')
+    def test_get_ip_nonlocal_bind(self, mIPWrapper):
+        cmd = ['sysctl', '-bn', ip_lib.IP_NONLOCAL_BIND]
+        ip_lib.get_ip_nonlocal_bind()
+        mIPWrapper.assert_has_calls([
+            mock.call().netns.execute(cmd, run_as_root=True, privsep_exec=True)
+        ])
+
+    @mock.patch.object(ip_lib, 'IPWrapper')
+    def test_get_ipv6_forwarding(self, mIPWrapper):
+        cmd = ['sysctl', '-b', 'net.ipv6.conf.tap0.forwarding']
+        ip_lib.get_ipv6_forwarding('tap0')
+        mIPWrapper.assert_has_calls([
+            mock.call().netns.execute(cmd, run_as_root=True, privsep_exec=True)
+        ])
+
+
 class TestConntrack(base.BaseTestCase):
     def setUp(self):
         super(TestConntrack, self).setUp()
