@@ -23,8 +23,11 @@ from neutron.tests import base
 
 class TestSanityCheck(base.BaseTestCase):
 
-    def test_setup_conf(self):
-        # verify that configuration can be successfully imported
-        with mock.patch.object(sanity_check.cfg, 'CONF',
-                               return_value=cfg.ConfigOpts()):
+    def test_setup_conf_and_enable_test_from_config(self):
+        # Verify that configuration can be successfully imported and tests are
+        # correctly loaded, based on the registered configuration parameters.
+        with mock.patch.object(sanity_check, 'cfg') as mock_cfg:
+            mock_cfg.CONF = cfg.ConfigOpts()
+            sanity_check.cfg.CONF.register_cli_opts(sanity_check.OPTS)
             sanity_check.setup_conf()
+            sanity_check.enable_tests_from_config()
