@@ -22,7 +22,7 @@ from neutron.tests.unit.conf.policies import test_base as base
 class NetworkAPITestCase(base.PolicyBaseTestCase):
 
     def setUp(self):
-        super(NetworkAPITestCase, self).setUp()
+        super().setUp()
         self.target = {'project_id': self.project_id}
         self.alt_target = {'project_id': self.alt_project_id}
 
@@ -30,7 +30,7 @@ class NetworkAPITestCase(base.PolicyBaseTestCase):
 class SystemAdminTests(NetworkAPITestCase):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.context = self.system_admin_ctx
 
     def test_create_network(self):
@@ -128,6 +128,15 @@ class SystemAdminTests(NetworkAPITestCase):
             self.context, 'create_network:provider:segmentation_id',
             self.alt_target)
 
+    def test_create_networks_tags(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce, self.context, 'create_networks_tags', self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce, self.context, 'create_networks_tags',
+            self.alt_target)
+
     def test_get_network(self):
         self.assertRaises(
             base_policy.InvalidScope,
@@ -321,21 +330,21 @@ class SystemAdminTests(NetworkAPITestCase):
 class SystemMemberTests(SystemAdminTests):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.context = self.system_member_ctx
 
 
 class SystemReaderTests(SystemMemberTests):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.context = self.system_reader_ctx
 
 
 class AdminTests(NetworkAPITestCase):
 
     def setUp(self):
-        super(AdminTests, self).setUp()
+        super().setUp()
         self.context = self.project_admin_ctx
 
     def test_create_network(self):
@@ -415,6 +424,13 @@ class AdminTests(NetworkAPITestCase):
                            'create_network:provider:segmentation_id',
                            self.alt_target))
 
+    def test_create_networks_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_networks_tags', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'create_networks_tags',
+                           self.alt_target))
+
     def test_get_network(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_network', self.target))
@@ -555,11 +571,11 @@ class AdminTests(NetworkAPITestCase):
                            self.alt_target))
 
 
-class ProjectMemberTests(AdminTests):
+class ProjectManagerTests(AdminTests):
 
     def setUp(self):
-        super(ProjectMemberTests, self).setUp()
-        self.context = self.project_member_ctx
+        super().setUp()
+        self.context = self.project_manager_ctx
 
     def test_create_network(self):
         self.assertTrue(
@@ -655,6 +671,14 @@ class ProjectMemberTests(AdminTests):
             self.context, 'create_network:provider:segmentation_id',
             self.alt_target)
 
+    def test_create_networks_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_networks_tags', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_networks_tags', self.alt_target)
+
     def test_get_network(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_network', self.target))
@@ -834,10 +858,17 @@ class ProjectMemberTests(AdminTests):
             self.context, 'delete_networks_tags', self.alt_target)
 
 
+class ProjectMemberTests(ProjectManagerTests):
+
+    def setUp(self):
+        super().setUp()
+        self.context = self.project_member_ctx
+
+
 class ProjectReaderTests(ProjectMemberTests):
 
     def setUp(self):
-        super(ProjectReaderTests, self).setUp()
+        super().setUp()
         self.context = self.project_reader_ctx
 
     def test_create_network(self):
@@ -860,6 +891,15 @@ class ProjectReaderTests(ProjectMemberTests):
             self.context, 'create_network:port_security_enabled',
             self.alt_target)
 
+    def test_create_networks_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_networks_tags', self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_networks_tags',
+            self.alt_target)
+
     def test_update_network(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
@@ -910,7 +950,7 @@ class ProjectReaderTests(ProjectMemberTests):
 class ServiceRoleTests(NetworkAPITestCase):
 
     def setUp(self):
-        super(ServiceRoleTests, self).setUp()
+        super().setUp()
         self.context = self.service_ctx
 
     def test_create_network(self):
@@ -969,6 +1009,11 @@ class ServiceRoleTests(NetworkAPITestCase):
             self.context, 'create_network:provider:segmentation_id',
             self.target)
 
+    def test_create_networks_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_networks_tags', self.target)
+
     def test_get_network(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_network', self.target))
