@@ -25,7 +25,7 @@ from neutron.tests.unit.conf.policies import test_base as base
 class PortAPITestCase(base.PolicyBaseTestCase):
 
     def setUp(self):
-        super(PortAPITestCase, self).setUp()
+        super().setUp()
 
         self.network = {
             'id': uuidutils.generate_uuid(),
@@ -51,7 +51,7 @@ class PortAPITestCase(base.PolicyBaseTestCase):
 class SystemAdminTests(PortAPITestCase):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.context = self.system_admin_ctx
 
     def test_create_port(self):
@@ -188,6 +188,14 @@ class SystemAdminTests(PortAPITestCase):
             self.context, 'create_port:allowed_address_pairs:ip_address',
             self.alt_target)
 
+    def test_create_ports_tags(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce, self.context, 'create_ports_tags', self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce, self.context, 'create_ports_tags', self.alt_target)
+
     def test_get_port(self):
         self.assertRaises(
             base_policy.InvalidScope,
@@ -410,21 +418,21 @@ class SystemAdminTests(PortAPITestCase):
 class SystemMemberTests(SystemAdminTests):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.context = self.system_member_ctx
 
 
 class SystemReaderTests(SystemMemberTests):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.context = self.system_reader_ctx
 
 
 class AdminTests(PortAPITestCase):
 
     def setUp(self):
-        super(AdminTests, self).setUp()
+        super().setUp()
         self.context = self.project_admin_ctx
 
     def test_create_port(self):
@@ -552,6 +560,22 @@ class AdminTests(PortAPITestCase):
                            'create_port:hints',
                            self.alt_target))
 
+    def test_create_port_with_trusted_field(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:trusted',
+                           self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:trusted',
+                           self.alt_target))
+
+    def test_create_ports_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_ports_tags', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'create_ports_tags', self.alt_target))
+
     def test_get_port(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_port', self.target))
@@ -606,6 +630,14 @@ class AdminTests(PortAPITestCase):
             policy.enforce(
                 self.context, 'get_port:hints', self.alt_target))
 
+    def test_get_port_trusted_field(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'get_port:trusted', self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'get_port:trusted', self.alt_target))
+
     def test_get_ports_tags(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_ports_tags', self.target))
@@ -747,6 +779,16 @@ class AdminTests(PortAPITestCase):
                            'update_port:hints',
                            self.alt_target))
 
+    def test_update_port_trusted_field(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:trusted',
+                           self.target))
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:trusted',
+                           self.alt_target))
+
     def test_delete_port(self):
         self.assertTrue(
             policy.enforce(self.context, 'delete_port', self.target))
@@ -754,11 +796,11 @@ class AdminTests(PortAPITestCase):
             policy.enforce(self.context, 'delete_port', self.alt_target))
 
 
-class ProjectMemberTests(AdminTests):
+class ProjectManagerTests(AdminTests):
 
     def setUp(self):
-        super(ProjectMemberTests, self).setUp()
-        self.context = self.project_member_ctx
+        super().setUp()
+        self.context = self.project_manager_ctx
 
     def test_create_port(self):
         self.assertTrue(
@@ -782,50 +824,45 @@ class ProjectMemberTests(AdminTests):
             alt_target)
 
     def test_create_port_with_mac_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:mac_address',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:mac_address', self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:mac_address',
             self.alt_target)
 
     def test_create_port_with_fixed_ips(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:fixed_ips',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:fixed_ips', self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:fixed_ips',
             self.alt_target)
 
     def test_create_port_with_fixed_ips_and_ip_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:fixed_ips:ip_address',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:fixed_ips:ip_address', self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:fixed_ips:ip_address',
             self.alt_target)
 
     def test_create_port_with_fixed_ips_and_subnet_id(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:fixed_ips:subnet_id',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:fixed_ips:subnet_id', self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:fixed_ips:subnet_id',
             self.alt_target)
 
     def test_create_port_with_port_security_enabled(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'create_port:port_security_enabled',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:port_security_enabled', self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, 'create_port:port_security_enabled',
@@ -861,11 +898,9 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_create_port_with_allowed_address_pairs(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_port:allowed_address_pairs',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:allowed_address_pairs', self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -873,11 +908,10 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_create_port_with_allowed_address_pairs_and_mac_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_port:allowed_address_pairs:mac_address',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:allowed_address_pairs:mac_address',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -885,11 +919,10 @@ class ProjectMemberTests(AdminTests):
             self.alt_target)
 
     def test_create_port_with_allowed_address_pairs_and_ip_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_port:allowed_address_pairs:ip_address',
-            self.target)
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_port:allowed_address_pairs:ip_address',
+                           self.target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -908,6 +941,25 @@ class ProjectMemberTests(AdminTests):
             self.context, 'create_port:hints',
             self.alt_target)
 
+    def test_create_port_with_trusted_field(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:trusted',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:trusted',
+            self.alt_target)
+
+    def test_create_ports_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_ports_tags', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_ports_tags', self.alt_target)
+
     def test_get_port(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_port', self.target))
@@ -975,6 +1027,16 @@ class ProjectMemberTests(AdminTests):
             policy.enforce, self.context, 'get_port:hints',
             self.alt_target)
 
+    def test_get_port_trusted_field(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'get_port:trusted',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'get_port:trusted',
+            self.alt_target)
+
     def test_get_ports_tags(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_ports_tags', self.target))
@@ -1003,6 +1065,277 @@ class ProjectMemberTests(AdminTests):
             policy.enforce, self.context, 'update_port:device_owner',
             alt_target)
 
+    def test_update_port_with_mac_address(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context, 'update_port:mac_address', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:mac_address',
+            self.alt_target)
+
+    def test_update_port_with_fixed_ips(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:fixed_ips', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:fixed_ips',
+            self.alt_target)
+
+    def test_update_port_with_fixed_ips_and_ip_address(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:fixed_ips:ip_address', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:fixed_ips:ip_address',
+            self.alt_target)
+
+    def test_update_port_with_fixed_ips_and_subnet_id(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:fixed_ips:subnet_id', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:fixed_ips:subnet_id',
+            self.alt_target)
+
+    def test_update_port_with_port_security_enabled(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:port_security_enabled', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:port_security_enabled',
+            self.alt_target)
+
+    def test_update_port_with_binding_host_id(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:binding:host_id',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:binding:host_id',
+            self.alt_target)
+
+    def test_update_port_with_binding_profile(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:binding:profile',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:binding:profile',
+            self.alt_target)
+
+    def test_update_port_with_binding_vnic_type(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:binding:vnic_type', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:binding:vnic_type',
+            self.alt_target)
+
+    def test_update_port_with_allowed_address_pairs(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:allowed_address_pairs', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs',
+            self.alt_target)
+
+    def test_update_port_with_allowed_address_pairs_and_mac_address(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:allowed_address_pairs:mac_address',
+                           self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs:mac_address',
+            self.alt_target)
+
+    def test_update_port_with_allowed_address_pairs_and_ip_address(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_port:allowed_address_pairs:ip_address',
+                           self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:allowed_address_pairs:ip_address',
+            self.alt_target)
+
+    def test_update_port_data_plane_status(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:data_plane_status', self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:data_plane_status', self.alt_target)
+
+    def test_update_port_hints(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:hints', self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:hints', self.alt_target)
+
+    def test_update_port_trusted_field(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:trusted', self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_port:trusted', self.alt_target)
+
+    def test_update_ports_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'update_ports_tags', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_ports_tags', self.alt_target)
+
+    def test_delete_port(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'delete_port', self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'delete_port', self.alt_target)
+
+
+class ProjectMemberTests(ProjectManagerTests):
+
+    def setUp(self):
+        super().setUp()
+        self.context = self.project_member_ctx
+
+    def test_create_port_with_device_owner(self):
+        target = self.target.copy()
+        target['device_owner'] = 'network:test'
+        alt_target = self.alt_target.copy()
+        alt_target['device_owner'] = 'network:test'
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:device_owner',
+            target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:device_owner',
+            alt_target)
+
+    def test_create_port_with_mac_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:mac_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:mac_address',
+            self.alt_target)
+
+    def test_create_port_with_fixed_ips(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips',
+            self.alt_target)
+
+    def test_create_port_with_fixed_ips_and_ip_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips:ip_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips:ip_address',
+            self.alt_target)
+
+    def test_create_port_with_fixed_ips_and_subnet_id(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips:subnet_id',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:fixed_ips:subnet_id',
+            self.alt_target)
+
+    def test_create_port_with_port_security_enabled(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:port_security_enabled',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_port:port_security_enabled',
+            self.alt_target)
+
+    def test_create_port_with_allowed_address_pairs(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs',
+            self.alt_target)
+
+    def test_create_port_with_allowed_address_pairs_and_mac_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:mac_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:mac_address',
+            self.alt_target)
+
+    def test_create_port_with_allowed_address_pairs_and_ip_address(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:ip_address',
+            self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_port:allowed_address_pairs:ip_address',
+            self.alt_target)
+
+    def test_update_port_with_device_owner(self):
+        target = self.target.copy()
+        target['device_owner'] = 'network:test'
+        alt_target = self.alt_target.copy()
+        alt_target['device_owner'] = 'network:test'
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:device_owner',
+            target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'update_port:device_owner',
+            alt_target)
+
     def test_update_port_with_mac_address(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
@@ -1053,35 +1386,6 @@ class ProjectMemberTests(AdminTests):
             policy.enforce, self.context, 'update_port:port_security_enabled',
             self.alt_target)
 
-    def test_update_port_with_binding_host_id(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:binding:host_id',
-            self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:binding:host_id',
-            self.alt_target)
-
-    def test_update_port_with_binding_profile(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:binding:profile',
-            self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:binding:profile',
-            self.alt_target)
-
-    def test_update_port_with_binding_vnic_type(self):
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'update_port:binding:vnic_type', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_port:binding:vnic_type',
-            self.alt_target)
-
     def test_update_port_with_allowed_address_pairs(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
@@ -1118,45 +1422,11 @@ class ProjectMemberTests(AdminTests):
             self.context, 'update_port:allowed_address_pairs:ip_address',
             self.alt_target)
 
-    def test_update_port_data_plane_status(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_port:data_plane_status', self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_port:data_plane_status', self.alt_target)
-
-    def test_update_port_hints(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_port:hints', self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_port:hints', self.alt_target)
-
-    def test_update_ports_tags(self):
-        self.assertTrue(
-            policy.enforce(self.context, 'update_ports_tags', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'update_ports_tags', self.alt_target)
-
-    def test_delete_port(self):
-        self.assertTrue(
-            policy.enforce(self.context, 'delete_port', self.target))
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce, self.context, 'delete_port', self.alt_target)
-
 
 class ProjectReaderTests(ProjectMemberTests):
 
     def setUp(self):
-        super(ProjectReaderTests, self).setUp()
+        super().setUp()
         self.context = self.project_reader_ctx
 
     def test_create_port(self):
@@ -1177,6 +1447,14 @@ class ProjectReaderTests(ProjectMemberTests):
             policy.enforce, self.context, 'create_port:binding:vnic_type',
             self.alt_target)
 
+    def test_create_ports_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_ports_tags', self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, 'create_ports_tags', self.alt_target)
+
     def test_update_port(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
@@ -1215,7 +1493,7 @@ class ProjectReaderTests(ProjectMemberTests):
 class ServiceRoleTests(PortAPITestCase):
 
     def setUp(self):
-        super(ServiceRoleTests, self).setUp()
+        super().setUp()
         self.context = self.service_ctx
 
     def test_create_port(self):
@@ -1289,6 +1567,13 @@ class ServiceRoleTests(PortAPITestCase):
             self.context, 'create_port:allowed_address_pairs:ip_address',
             self.target)
 
+    def test_create_ports_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_ports_tags',
+            self.target)
+
     def test_get_port(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_port', self.target))
