@@ -15,6 +15,9 @@
 
 from unittest import mock
 
+from neutron_lib.api import attributes
+from neutron_lib.api.definitions import subnet as subnet_def
+from neutron_lib.api.definitions import subnet_external_network as sen_def
 from oslo_policy import policy as base_policy
 from oslo_utils import uuidutils
 
@@ -25,7 +28,12 @@ from neutron.tests.unit.conf.policies import test_base as base
 class SubnetAPITestCase(base.PolicyBaseTestCase):
 
     def setUp(self):
-        super(SubnetAPITestCase, self).setUp()
+        # Extend subnet "subnet-external-network" extension. This extension
+        # is not loaded in the unit tests.
+        rname = subnet_def.COLLECTION_NAME
+        attributes.RESOURCES[rname].update(
+            sen_def.RESOURCE_ATTRIBUTE_MAP[rname])
+        super().setUp()
 
         self.network = {
             'id': uuidutils.generate_uuid(),
@@ -35,17 +43,23 @@ class SubnetAPITestCase(base.PolicyBaseTestCase):
             'id': uuidutils.generate_uuid(),
             'tenant_id': self.alt_project_id,
             'project_id': self.alt_project_id}
+        self.ext_alt_network = {
+            'id': uuidutils.generate_uuid(),
+            'tenant_id': self.alt_project_id,
+            'project_id': self.alt_project_id}
 
         networks = {
             self.network['id']: self.network,
-            self.alt_network['id']: self.alt_network}
+            self.alt_network['id']: self.alt_network,
+            self.ext_alt_network['id']: self.ext_alt_network,
+        }
 
         self.target = {
             'project_id': self.project_id,
             'tenant_id': self.project_id,
             'network_id': self.network['id'],
             'ext_parent_network_id': self.network['id']}
-        # This network belongs to "project_id", but not the network that
+        # This subnet belongs to "project_id", but not the network that
         # belongs to "alt_project_id".
         self.target_net_alt_target = {
             'project_id': self.project_id,
@@ -57,13 +71,14 @@ class SubnetAPITestCase(base.PolicyBaseTestCase):
             'tenant_id': self.alt_project_id,
             'network_id': self.alt_network['id'],
             'ext_parent_network_id': self.alt_network['id']}
-        # This is the case where the network belongs to the project but not
-        # the subnet.
-        self.alt_target_own_net = {
+        # Both the subnet and the network belongs to "alt_project_id" and the
+        # network is external.
+        self.target_net_ext_alt_target = {
             'project_id': self.alt_project_id,
             'tenant_id': self.alt_project_id,
-            'network_id': self.network['id'],
-            'ext_parent_network_id': self.network['id']}
+            'network_id': self.ext_alt_network['id'],
+            'ext_parent_network_id': self.ext_alt_network['id'],
+            'router:external': True}
 
         def get_network(context, id, fields=None):
             return networks.get(id)
@@ -78,7 +93,7 @@ class SubnetAPITestCase(base.PolicyBaseTestCase):
 class SystemAdminTests(SubnetAPITestCase):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.context = self.system_admin_ctx
 
     def test_create_subnet(self):
@@ -94,10 +109,6 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'create_subnet', self.alt_target)
-        self.assertRaises(
-            base_policy.InvalidScope,
-            policy.enforce,
-            self.context, 'create_subnet', self.alt_target_own_net)
 
     def test_create_subnet_segment_id(self):
         self.assertRaises(
@@ -113,10 +124,6 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'create_subnet:segment_id', self.alt_target)
-        self.assertRaises(
-            base_policy.InvalidScope,
-            policy.enforce,
-            self.context, 'create_subnet:segment_id', self.alt_target_own_net)
 
     def test_create_subnet_service_types(self):
         self.assertRaises(
@@ -132,11 +139,20 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'create_subnet:service_types', self.alt_target)
+
+    def test_create_subnets_tags(self):
         self.assertRaises(
             base_policy.InvalidScope,
             policy.enforce,
-            self.context, 'create_subnet:service_types',
-            self.alt_target_own_net)
+            self.context, 'create_subnets_tags', self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'create_subnets_tags', self.target_net_alt_target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'create_subnets_tags', self.alt_target)
 
     def test_get_subnet(self):
         self.assertRaises(
@@ -150,11 +166,11 @@ class SystemAdminTests(SubnetAPITestCase):
         self.assertRaises(
             base_policy.InvalidScope,
             policy.enforce,
-            self.context, 'get_subnet', self.alt_target)
+            self.context, 'get_subnet', self.target_net_ext_alt_target)
         self.assertRaises(
             base_policy.InvalidScope,
             policy.enforce,
-            self.context, 'get_subnet', self.alt_target_own_net)
+            self.context, 'get_subnet', self.alt_target)
 
     def test_get_subnet_segment_id(self):
         self.assertRaises(
@@ -169,10 +185,6 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'get_subnet:segment_id', self.alt_target)
-        self.assertRaises(
-            base_policy.InvalidScope,
-            policy.enforce,
-            self.context, 'get_subnet:segment_id', self.alt_target_own_net)
 
     def test_get_subnets_tags(self):
         self.assertRaises(
@@ -186,11 +198,11 @@ class SystemAdminTests(SubnetAPITestCase):
         self.assertRaises(
             base_policy.InvalidScope,
             policy.enforce,
-            self.context, 'get_subnets_tags', self.alt_target)
+            self.context, 'get_subnets_tags', self.target_net_ext_alt_target)
         self.assertRaises(
             base_policy.InvalidScope,
             policy.enforce,
-            self.context, 'get_subnets_tags', self.alt_target_own_net)
+            self.context, 'get_subnets_tags', self.alt_target)
 
     def test_update_subnet(self):
         self.assertRaises(
@@ -205,10 +217,6 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'update_subnet', self.alt_target)
-        self.assertRaises(
-            base_policy.InvalidScope,
-            policy.enforce,
-            self.context, 'update_subnet', self.alt_target_own_net)
 
     def test_update_subnet_segment_id(self):
         self.assertRaises(
@@ -224,10 +232,6 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'update_subnet:segment_id', self.alt_target)
-        self.assertRaises(
-            base_policy.InvalidScope,
-            policy.enforce,
-            self.context, 'update_subnet:segment_id', self.alt_target_own_net)
 
     def test_update_subnet_service_types(self):
         self.assertRaises(
@@ -243,11 +247,6 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'update_subnet:service_types', self.alt_target)
-        self.assertRaises(
-            base_policy.InvalidScope,
-            policy.enforce,
-            self.context, 'update_subnet:service_types',
-            self.alt_target_own_net)
 
     def test_update_subnets_tags(self):
         self.assertRaises(
@@ -262,10 +261,6 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'update_subnets_tags', self.alt_target)
-        self.assertRaises(
-            base_policy.InvalidScope,
-            policy.enforce,
-            self.context, 'update_subnets_tags', self.alt_target_own_net)
 
     def test_delete_subnet(self):
         self.assertRaises(
@@ -280,10 +275,6 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'delete_subnet', self.alt_target)
-        self.assertRaises(
-            base_policy.InvalidScope,
-            policy.enforce,
-            self.context, 'delete_subnet', self.alt_target_own_net)
 
     def test_delete_subnets_tags(self):
         self.assertRaises(
@@ -298,30 +289,26 @@ class SystemAdminTests(SubnetAPITestCase):
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'delete_subnets_tags', self.alt_target)
-        self.assertRaises(
-            base_policy.InvalidScope,
-            policy.enforce,
-            self.context, 'delete_subnets_tags', self.alt_target_own_net)
 
 
 class SystemMemberTests(SystemAdminTests):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.context = self.system_member_ctx
 
 
 class SystemReaderTests(SystemMemberTests):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.context = self.system_reader_ctx
 
 
 class AdminTests(SubnetAPITestCase):
 
     def setUp(self):
-        super(AdminTests, self).setUp()
+        super().setUp()
         self.context = self.project_admin_ctx
 
     def test_create_subnet(self):
@@ -332,9 +319,6 @@ class AdminTests(SubnetAPITestCase):
                            self.target_net_alt_target))
         self.assertTrue(
             policy.enforce(self.context, 'create_subnet', self.alt_target))
-        self.assertTrue(
-            policy.enforce(self.context, 'create_subnet',
-                           self.alt_target_own_net))
 
     def test_create_subnet_segment_id(self):
         self.assertTrue(
@@ -347,10 +331,6 @@ class AdminTests(SubnetAPITestCase):
         self.assertTrue(
             policy.enforce(
                 self.context, 'create_subnet:segment_id', self.alt_target))
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'create_subnet:segment_id',
-                self.alt_target_own_net))
 
     def test_create_subnet_service_types(self):
         self.assertTrue(
@@ -363,10 +343,16 @@ class AdminTests(SubnetAPITestCase):
         self.assertTrue(
             policy.enforce(
                 self.context, 'create_subnet:service_types', self.alt_target))
+
+    def test_create_subnets_tags(self):
         self.assertTrue(
-            policy.enforce(
-                self.context, 'create_subnet:service_types',
-                self.alt_target_own_net))
+            policy.enforce(self.context, 'create_subnets_tags', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'create_subnets_tags',
+                           self.target_net_alt_target))
+        self.assertTrue(
+            policy.enforce(self.context, 'create_subnets_tags',
+                           self.alt_target))
 
     def test_get_subnet(self):
         self.assertTrue(
@@ -374,11 +360,11 @@ class AdminTests(SubnetAPITestCase):
         self.assertTrue(
             policy.enforce(self.context, 'get_subnet',
                            self.target_net_alt_target))
-        self.assertTrue(
-            policy.enforce(self.context, 'get_subnet', self.alt_target))
         self.assertTrue(
             policy.enforce(self.context, 'get_subnet',
-                           self.alt_target_own_net))
+                           self.target_net_ext_alt_target))
+        self.assertTrue(
+            policy.enforce(self.context, 'get_subnet', self.alt_target))
 
     def test_get_subnet_segment_id(self):
         self.assertTrue(
@@ -389,10 +375,6 @@ class AdminTests(SubnetAPITestCase):
         self.assertTrue(
             policy.enforce(
                 self.context, 'get_subnet:segment_id', self.alt_target))
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'get_subnet:segment_id',
-                self.alt_target_own_net))
 
     def test_get_subnets_tags(self):
         self.assertTrue(
@@ -400,11 +382,11 @@ class AdminTests(SubnetAPITestCase):
         self.assertTrue(
             policy.enforce(self.context, 'get_subnets_tags',
                            self.target_net_alt_target))
-        self.assertTrue(
-            policy.enforce(self.context, 'get_subnets_tags', self.alt_target))
         self.assertTrue(
             policy.enforce(self.context, 'get_subnets_tags',
-                           self.alt_target_own_net))
+                           self.target_net_ext_alt_target))
+        self.assertTrue(
+            policy.enforce(self.context, 'get_subnets_tags', self.alt_target))
 
     def test_update_subnet(self):
         self.assertTrue(
@@ -414,9 +396,6 @@ class AdminTests(SubnetAPITestCase):
                            self.target_net_alt_target))
         self.assertTrue(
             policy.enforce(self.context, 'update_subnet', self.alt_target))
-        self.assertTrue(
-            policy.enforce(self.context, 'update_subnet',
-                           self.alt_target_own_net))
 
     def test_update_subnet_segment_id(self):
         self.assertTrue(
@@ -429,10 +408,6 @@ class AdminTests(SubnetAPITestCase):
         self.assertTrue(
             policy.enforce(
                 self.context, 'update_subnet:segment_id', self.alt_target))
-        self.assertTrue(
-            policy.enforce(
-                self.context, 'update_subnet:segment_id',
-                self.alt_target_own_net))
 
     def test_update_subnet_service_types(self):
         self.assertTrue(
@@ -455,9 +430,6 @@ class AdminTests(SubnetAPITestCase):
         self.assertTrue(
             policy.enforce(self.context, 'update_subnets_tags',
                            self.alt_target))
-        self.assertTrue(
-            policy.enforce(self.context, 'update_subnets_tags',
-                           self.alt_target_own_net))
 
     def test_delete_subnet(self):
         self.assertTrue(
@@ -467,9 +439,6 @@ class AdminTests(SubnetAPITestCase):
                            self.target_net_alt_target))
         self.assertTrue(
             policy.enforce(self.context, 'delete_subnet', self.alt_target))
-        self.assertTrue(
-            policy.enforce(self.context, 'delete_subnet',
-                           self.alt_target_own_net))
 
     def test_delete_subnets_tags(self):
         self.assertTrue(
@@ -480,16 +449,13 @@ class AdminTests(SubnetAPITestCase):
         self.assertTrue(
             policy.enforce(self.context, 'delete_subnets_tags',
                            self.alt_target))
-        self.assertTrue(
-            policy.enforce(self.context, 'delete_subnets_tags',
-                           self.alt_target_own_net))
 
 
-class ProjectMemberTests(AdminTests):
+class ProjectManagerTests(AdminTests):
 
     def setUp(self):
-        super(ProjectMemberTests, self).setUp()
-        self.context = self.project_member_ctx
+        super().setUp()
+        self.context = self.project_manager_ctx
 
     def test_create_subnet(self):
         self.assertTrue(
@@ -502,9 +468,6 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'create_subnet', self.alt_target)
-        self.assertTrue(
-            policy.enforce(self.context, 'create_subnet',
-                           self.alt_target_own_net))
 
     def test_create_subnet_segment_id(self):
         self.assertRaises(
@@ -520,10 +483,6 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'create_subnet:segment_id', self.alt_target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_subnet:segment_id', self.alt_target_own_net)
 
     def test_create_subnet_service_types(self):
         self.assertRaises(
@@ -539,11 +498,17 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'create_subnet:service_types', self.alt_target)
+
+    def test_create_subnets_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_subnets_tags', self.target))
+        self.assertTrue(
+            policy.enforce(self.context, 'create_subnets_tags',
+                           self.target_net_alt_target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
-            self.context, 'create_subnet:service_types',
-            self.alt_target_own_net)
+            self.context, 'create_subnets_tags', self.alt_target)
 
     def test_get_subnet(self):
         self.assertTrue(
@@ -551,13 +516,13 @@ class ProjectMemberTests(AdminTests):
         self.assertTrue(
             policy.enforce(self.context, 'get_subnet',
                            self.target_net_alt_target))
+        self.assertTrue(
+            policy.enforce(self.context, 'get_subnet',
+                           self.target_net_ext_alt_target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'get_subnet', self.alt_target)
-        self.assertTrue(
-            policy.enforce(self.context, 'get_subnet',
-                           self.alt_target_own_net))
 
     def test_get_subnet_segment_id(self):
         self.assertRaises(
@@ -572,10 +537,6 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'get_subnet:segment_id', self.alt_target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'get_subnet:segment_id', self.alt_target_own_net)
 
     def test_get_subnets_tags(self):
         self.assertTrue(
@@ -583,13 +544,13 @@ class ProjectMemberTests(AdminTests):
         self.assertTrue(
             policy.enforce(self.context, 'get_subnets_tags',
                            self.target_net_alt_target))
+        self.assertTrue(
+            policy.enforce(self.context, 'get_subnets_tags',
+                           self.target_net_ext_alt_target))
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'get_subnets_tags', self.alt_target)
-        self.assertTrue(
-            policy.enforce(self.context, 'get_subnets_tags',
-                           self.alt_target_own_net))
 
     def test_update_subnet(self):
         self.assertTrue(
@@ -601,9 +562,6 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'update_subnet', self.alt_target)
-        self.assertTrue(
-            policy.enforce(self.context, 'update_subnet',
-                           self.alt_target_own_net))
 
     def test_update_subnet_segment_id(self):
         self.assertRaises(
@@ -619,10 +577,6 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'update_subnet:segment_id', self.alt_target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_subnet:segment_id', self.alt_target_own_net)
 
     def test_update_subnet_service_types(self):
         self.assertRaises(
@@ -638,11 +592,6 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'update_subnet:service_types', self.alt_target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_subnet:service_types',
-            self.alt_target_own_net)
 
     def test_update_subnets_tags(self):
         self.assertTrue(
@@ -654,9 +603,6 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'update_subnets_tags', self.alt_target)
-        self.assertTrue(
-            policy.enforce(self.context, 'update_subnets_tags',
-                           self.alt_target_own_net))
 
     def test_delete_subnet(self):
         self.assertTrue(
@@ -668,9 +614,6 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'delete_subnet', self.alt_target)
-        self.assertTrue(
-            policy.enforce(self.context, 'delete_subnet',
-                           self.alt_target_own_net))
 
     def test_delete_subnets_tags(self):
         self.assertTrue(
@@ -682,15 +625,19 @@ class ProjectMemberTests(AdminTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'delete_subnets_tags', self.alt_target)
-        self.assertTrue(
-            policy.enforce(self.context, 'delete_subnets_tags',
-                           self.alt_target_own_net))
+
+
+class ProjectMemberTests(ProjectManagerTests):
+
+    def setUp(self):
+        super().setUp()
+        self.context = self.project_member_ctx
 
 
 class ProjectReaderTests(ProjectMemberTests):
 
     def setUp(self):
-        super(ProjectReaderTests, self).setUp()
+        super().setUp()
         self.context = self.project_reader_ctx
 
     def test_create_subnet(self):
@@ -706,10 +653,20 @@ class ProjectReaderTests(ProjectMemberTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'create_subnet', self.alt_target)
+
+    def test_create_subnets_tags(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
-            self.context, 'create_subnet', self.alt_target_own_net)
+            self.context, 'create_subnets_tags', self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_subnets_tags', self.target_net_alt_target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_subnets_tags', self.alt_target)
 
     def test_update_subnet(self):
         self.assertRaises(
@@ -724,10 +681,6 @@ class ProjectReaderTests(ProjectMemberTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'update_subnet', self.alt_target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_subnet', self.alt_target_own_net)
 
     def test_update_subnets_tags(self):
         self.assertRaises(
@@ -742,10 +695,6 @@ class ProjectReaderTests(ProjectMemberTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'update_subnets_tags', self.alt_target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_subnets_tags', self.alt_target_own_net)
 
     def test_delete_subnet(self):
         self.assertRaises(
@@ -760,10 +709,6 @@ class ProjectReaderTests(ProjectMemberTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'delete_subnet', self.alt_target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'delete_subnet', self.alt_target_own_net)
 
     def test_delete_subnets_tags(self):
         self.assertRaises(
@@ -778,16 +723,12 @@ class ProjectReaderTests(ProjectMemberTests):
             base_policy.PolicyNotAuthorized,
             policy.enforce,
             self.context, 'delete_subnets_tags', self.alt_target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'delete_subnets_tags', self.alt_target_own_net)
 
 
 class ServiceRoleTests(SubnetAPITestCase):
 
     def setUp(self):
-        super(ServiceRoleTests, self).setUp()
+        super().setUp()
         self.context = self.service_ctx
 
     def test_create_subnet(self):
@@ -808,6 +749,12 @@ class ServiceRoleTests(SubnetAPITestCase):
             policy.enforce,
             self.context, 'create_subnet:service_types', self.target)
 
+    def test_create_subnets_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_subnets_tags', self.target)
+
     def test_get_subnet(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
