@@ -22,7 +22,7 @@ from neutron.tests.unit.conf.policies import test_base as base
 class SubnetpoolAPITestCase(base.PolicyBaseTestCase):
 
     def setUp(self):
-        super(SubnetpoolAPITestCase, self).setUp()
+        super().setUp()
         self.target = {'project_id': self.project_id}
         self.alt_target = {'project_id': self.alt_project_id}
 
@@ -30,7 +30,7 @@ class SubnetpoolAPITestCase(base.PolicyBaseTestCase):
 class SystemAdminTests(SubnetpoolAPITestCase):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.context = self.system_admin_ctx
 
     def test_create_subnetpool(self):
@@ -63,6 +63,16 @@ class SystemAdminTests(SubnetpoolAPITestCase):
             policy.enforce,
             self.context, 'create_subnetpool:is_default', self.alt_target)
 
+    def test_create_subnetpools_tags(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'create_subnetpools_tags', self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'create_subnetpools_tags', self.alt_target)
+
     def test_get_subnetpool(self):
         self.assertRaises(
             base_policy.InvalidScope,
@@ -167,21 +177,21 @@ class SystemAdminTests(SubnetpoolAPITestCase):
 class SystemMemberTests(SystemAdminTests):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.context = self.system_member_ctx
 
 
 class SystemReaderTests(SystemMemberTests):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.context = self.system_reader_ctx
 
 
 class AdminTests(SubnetpoolAPITestCase):
 
     def setUp(self):
-        super(AdminTests, self).setUp()
+        super().setUp()
         self.context = self.project_admin_ctx
 
     def test_create_subnetpool(self):
@@ -206,6 +216,13 @@ class AdminTests(SubnetpoolAPITestCase):
             policy.enforce(
                 self.context, 'create_subnetpool:default', self.alt_target))
 
+    def test_create_subnetpools_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_subnetpools_tags',
+                           self.target))
+        self.assertTrue(policy.enforce(self.context, 'create_subnetpools_tags',
+                                       self.alt_target))
+
     def test_get_subnetpool(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_subnetpool', self.target))
@@ -276,11 +293,11 @@ class AdminTests(SubnetpoolAPITestCase):
             policy.enforce(self.context, 'remove_prefixes', self.alt_target))
 
 
-class ProjectMemberTests(AdminTests):
+class ProjectManagerTests(AdminTests):
 
     def setUp(self):
-        super(ProjectMemberTests, self).setUp()
-        self.context = self.project_member_ctx
+        super().setUp()
+        self.context = self.project_manager_ctx
 
     def test_create_subnetpool(self):
         self.assertTrue(
@@ -310,6 +327,15 @@ class ProjectMemberTests(AdminTests):
             policy.enforce,
             self.context, 'create_subnetpool:is_default', self.alt_target)
 
+    def test_create_subnetpools_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, 'create_subnetpools_tags',
+                           self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_subnetpools_tags', self.alt_target)
+
     def test_get_subnetpool(self):
         self.assertTrue(
             policy.enforce(self.context, 'get_subnetpool', self.target))
@@ -396,10 +422,17 @@ class ProjectMemberTests(AdminTests):
             self.context, 'remove_prefixes', self.alt_target)
 
 
+class ProjectMemberTests(ProjectManagerTests):
+
+    def setUp(self):
+        super().setUp()
+        self.context = self.project_member_ctx
+
+
 class ProjectReaderTests(ProjectMemberTests):
 
     def setUp(self):
-        super(ProjectReaderTests, self).setUp()
+        super().setUp()
         self.context = self.project_reader_ctx
 
     def test_create_subnetpool(self):
@@ -412,6 +445,16 @@ class ProjectReaderTests(ProjectMemberTests):
             policy.enforce,
             self.context, 'create_subnetpool', self.alt_target)
 
+    def test_create_subnetpools_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_subnetpools_tags', self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_subnetpools_tags', self.alt_target)
+
     def test_update_subnetpool(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
@@ -486,7 +529,7 @@ class ProjectReaderTests(ProjectMemberTests):
 class ServiceRoleTests(SubnetpoolAPITestCase):
 
     def setUp(self):
-        super(ServiceRoleTests, self).setUp()
+        super().setUp()
         self.context = self.service_ctx
 
     def test_create_subnetpool(self):
@@ -495,6 +538,12 @@ class ServiceRoleTests(SubnetpoolAPITestCase):
             policy.enforce,
             self.context, 'create_subnetpool', self.target)
 
+    def test_create_subnetpools_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_subnetpools_tags', self.target)
+
     def test_create_subnetpool_shared(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
