@@ -40,6 +40,7 @@ from neutron.api.rpc.agentnotifiers import dhcp_rpc_agent_api
 from neutron.api.rpc.agentnotifiers import l3_rpc_agent_api
 from neutron.api.rpc.handlers import dhcp_rpc
 from neutron.api.rpc.handlers import l3_rpc
+from neutron.api import wsgi
 from neutron.db import agents_db
 from neutron.db import agentschedulers_db
 from neutron.db.models import agent as agent_model
@@ -53,7 +54,6 @@ from neutron.tests.unit.db import test_db_base_plugin_v2 as test_plugin
 from neutron.tests.unit.extensions import test_agent
 from neutron.tests.unit.extensions import test_l3
 from neutron.tests.unit import testlib_api
-from neutron import wsgi
 
 
 L3_HOSTA = 'hosta'
@@ -1583,27 +1583,22 @@ class OvsDhcpAgentNotifierTestCase(test_agent.AgentDBTestMixIn,
         hosts = [DHCP_HOSTA, DHCP_HOSTC, DHCP_HOSTD]
         net, subnet, port = self._network_port_create(hosts)
         for host_call in self.dhcp_notifier_cast.call_args_list:
+            host_call = str(host_call)
             if ("'priority': " + str(
                     dhcp_rpc_agent_api.PRIORITY_PORT_CREATE_HIGH)
-                    in str(host_call)):
-                if DHCP_HOSTA in str(host_call):
-                    expected_high_calls = self._notification_mocks(
-                        [DHCP_HOSTA], net, subnet, port,
-                        dhcp_rpc_agent_api.PRIORITY_PORT_CREATE_HIGH)
+                    in host_call):
+                if DHCP_HOSTA in host_call:
                     high_host = DHCP_HOSTA
                     hosts.pop(0)
-                elif DHCP_HOSTC in str(host_call):
-                    expected_high_calls = self._notification_mocks(
-                        [DHCP_HOSTC], net, subnet, port,
-                        dhcp_rpc_agent_api.PRIORITY_PORT_CREATE_HIGH)
+                elif DHCP_HOSTC in host_call:
                     high_host = DHCP_HOSTC
                     hosts.pop(1)
-                elif DHCP_HOSTD in str(host_call):
-                    expected_high_calls = self._notification_mocks(
-                        [DHCP_HOSTD], net, subnet, port,
-                        dhcp_rpc_agent_api.PRIORITY_PORT_CREATE_HIGH)
+                elif DHCP_HOSTD in host_call:
                     high_host = DHCP_HOSTD
                     hosts.pop(2)
+        expected_high_calls = self._notification_mocks(
+            [high_host], net, subnet, port,
+            dhcp_rpc_agent_api.PRIORITY_PORT_CREATE_HIGH)
         expected_low_calls = self._notification_mocks(
             hosts, net, subnet, port,
             dhcp_rpc_agent_api.PRIORITY_PORT_CREATE_LOW)
