@@ -33,6 +33,7 @@ from neutron_lib.plugins import directory
 from neutron_lib.plugins import utils as plugin_utils
 from oslo_utils import uuidutils
 import testtools
+import webob.exc
 
 from neutron.db import extraroute_db
 from neutron.db import l3_db
@@ -1048,7 +1049,8 @@ class L3TestCase(test_db_base_plugin_v2.NeutronDbPluginV2TestCase):
                 self.fmt, name, True,
                 arg_list=(extnet_apidef.EXTERNAL,),
                 as_admin=True, **kwargs)
-            self._check_http_response(res)
+            if res.status_int >= webob.exc.HTTPClientError.code:
+                raise webob.exc.HTTPClientError(code=res.status_int)
             return self.deserialize(self.fmt, res)
 
     def test_update_router_gw_notify(self):
