@@ -463,6 +463,37 @@ class TestUpdateLRouterCommand(TestBaseCommand):
             self.assertEqual(new_ext_ids, fake_lrouter.external_ids)
 
 
+class TestLrDelCommand(TestBaseCommand):
+
+    def _test_lrouter_del_no_exist(self, if_exists=True):
+        with mock.patch.object(self.ovn_api, 'lookup',
+                               side_effect=idlutils.RowNotFound):
+            cmd = commands.LrDelCommand(
+                self.ovn_api, 'fake-lrouter', if_exists=if_exists)
+            if if_exists:
+                cmd.run_idl(self.transaction)
+            else:
+                self.assertRaises(RuntimeError, cmd.run_idl, self.transaction)
+
+    def test_lrouter_no_exist_ignore(self):
+        self._test_lrouter_del_no_exist(if_exists=True)
+
+    def test_lrouter_no_exist_fail(self):
+        self._test_lrouter_del_no_exist(if_exists=False)
+
+    def test_lrouter_del(self):
+        fake_lrouter = fakes.FakeOvsdbRow.create_one_ovsdb_row()
+        fake_hcg = fakes.FakeOvsdbRow.create_one_ovsdb_row()
+        self.ovn_api._tables['Logical_Router'].rows[fake_lrouter.uuid] = \
+            fake_lrouter
+        with mock.patch.object(self.ovn_api, 'lookup',
+                               side_effect=[fake_lrouter, fake_hcg]):
+            cmd = commands.LrDelCommand(
+                self.ovn_api, fake_lrouter.name, if_exists=True)
+            cmd.run_idl(self.transaction)
+            fake_lrouter.delete.assert_called_once_with()
+
+
 class TestAddLRouterPortCommand(TestBaseCommand):
 
     def test_lrouter_not_found(self):
@@ -699,14 +730,14 @@ class TestAddStaticRouteCommand(TestBaseCommand):
                 'static_routes', fake_static_route.uuid)
 
 
-class TestDelStaticRouteCommand(TestBaseCommand):
+class TestDelStaticRoutesCommand(TestBaseCommand):
 
     def _test_lrouter_no_exist(self, if_exists=True):
         with mock.patch.object(idlutils, 'row_by_value',
                                side_effect=idlutils.RowNotFound):
-            cmd = commands.DelStaticRouteCommand(
+            cmd = commands.DelStaticRoutesCommand(
                 self.ovn_api, 'fake-lrouter',
-                '30.0.0.0/24', '40.0.0.100',
+                [('30.0.0.0/24', '40.0.0.100')],
                 if_exists=if_exists)
             if if_exists:
                 cmd.run_idl(self.transaction)
@@ -720,18 +751,21 @@ class TestDelStaticRouteCommand(TestBaseCommand):
         self._test_lrouter_no_exist(if_exists=False)
 
     def test_static_route_del(self):
-        fake_static_route = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+        fake_static_route1 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
             attrs={'ip_prefix': '50.0.0.0/24', 'nexthop': '40.0.0.101'})
+        fake_static_route2 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={'ip_prefix': '60.0.0.0/24', 'nexthop': '40.0.0.101'})
         fake_lrouter = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'static_routes': [fake_static_route]})
+            attrs={'static_routes': [fake_static_route1, fake_static_route2]})
         with mock.patch.object(idlutils, 'row_by_value',
                                return_value=fake_lrouter):
-            cmd = commands.DelStaticRouteCommand(
+            cmd = commands.DelStaticRoutesCommand(
                 self.ovn_api, fake_lrouter.name,
-                fake_static_route.ip_prefix, fake_static_route.nexthop,
+                [(fake_static_route1.ip_prefix, fake_static_route1.nexthop),
+                 (fake_static_route2.ip_prefix, fake_static_route2.nexthop)],
                 if_exists=True)
             cmd.run_idl(self.transaction)
-            fake_lrouter.delvalue.assert_called_once_with(
+            fake_lrouter.delvalue.assert_called_with(
                 'static_routes', mock.ANY)
 
     def test_static_route_del_not_found(self):
@@ -743,9 +777,9 @@ class TestDelStaticRouteCommand(TestBaseCommand):
             attrs={'static_routes': [fake_static_route2]})
         with mock.patch.object(idlutils, 'row_by_value',
                                return_value=fake_lrouter):
-            cmd = commands.DelStaticRouteCommand(
+            cmd = commands.DelStaticRoutesCommand(
                 self.ovn_api, fake_lrouter.name,
-                fake_static_route1.ip_prefix, fake_static_route1.nexthop,
+                [(fake_static_route1.ip_prefix, fake_static_route1.nexthop)],
                 if_exists=True)
             cmd.run_idl(self.transaction)
             fake_lrouter.delvalue.assert_not_called()
