@@ -16,6 +16,7 @@
 from unittest import mock
 
 from futurist import periodics
+from neutron_lib.api.definitions import external_net
 from neutron_lib.api.definitions import portbindings
 from neutron_lib import constants as n_const
 from neutron_lib import context
@@ -396,18 +397,19 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
         self.assertFalse(
             self.fake_ovn_client._nb_idl.ha_chassis_group_add.called)
 
-    @mock.patch.object(utils, 'sync_ha_chassis_group')
+    @mock.patch.object(utils, 'sync_ha_chassis_group_network')
     def test_check_for_ha_chassis_group_no_external_ports(
-            self, mock_sync_ha_chassis_group):
+            self, mock_sync_ha_chassis_group_network):
         self.fake_ovn_client.is_external_ports_supported.return_value = True
         nb_idl = self.fake_ovn_client._nb_idl
         nb_idl.db_find_rows.return_value.execute.return_value = []
         self.assertRaises(periodics.NeverAgain,
                           self.periodic.check_for_ha_chassis_group)
-        self.assertFalse(mock_sync_ha_chassis_group.called)
+        self.assertFalse(mock_sync_ha_chassis_group_network.called)
 
-    @mock.patch.object(utils, 'sync_ha_chassis_group')
-    def test_check_for_ha_chassis_group(self, mock_sync_ha_chassis_group):
+    @mock.patch.object(utils, 'sync_ha_chassis_group_network')
+    def test_check_for_ha_chassis_group(self,
+                                        mock_sync_ha_chassis_group_network):
         self.fake_ovn_client.is_external_ports_supported.return_value = True
         nb_idl = self.fake_ovn_client._nb_idl
 
@@ -431,24 +433,22 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
                        constants.OVN_NETWORK_NAME_EXT_ID_KEY: 'neutron-net1'}})
 
         nb_idl.db_find_rows.return_value.execute.return_value = [p0, p1]
-        mock_sync_ha_chassis_group.return_value = hcg0.uuid
+        mock_sync_ha_chassis_group_network.return_value = hcg0.uuid, mock.ANY
 
         # Invoke the periodic method, it meant to run only once at startup
         # so NeverAgain will be raised at the end
         self.assertRaises(periodics.NeverAgain,
                           self.periodic.check_for_ha_chassis_group)
 
-        # Assert sync_ha_chassis_group() is called for both networks
+        # Assert sync_ha_chassis_group_network() is called for both networks
         expected_calls = [
-            mock.call(mock.ANY, 'p0', 'net0',
-                      self.fake_ovn_client._nb_idl,
-                      self.fake_ovn_client._sb_idl, mock.ANY),
-            mock.call(mock.ANY, 'p1', 'net1',
-                      self.fake_ovn_client._nb_idl,
-                      self.fake_ovn_client._sb_idl, mock.ANY),
+            mock.call(mock.ANY, self.fake_ovn_client._nb_idl,
+                      self.fake_ovn_client._sb_idl, 'p0', 'net0', mock.ANY),
+            mock.call(mock.ANY, self.fake_ovn_client._nb_idl,
+                      self.fake_ovn_client._sb_idl, 'p1', 'net1', mock.ANY),
         ]
-        mock_sync_ha_chassis_group.assert_has_calls(expected_calls,
-                                                    any_order=True)
+        mock_sync_ha_chassis_group_network.assert_has_calls(expected_calls,
+                                                            any_order=True)
 
         expected_calls = [
             mock.call('p0', ha_chassis_group=hcg0.uuid),
@@ -752,13 +752,22 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
         nb_idl.db_set.assert_has_calls(expected_calls)
 
     def _test_check_redirect_type_router_gateway_ports(self, networks,
-                                                       redirect_value):
+                                                       redirect_value,
+                                                       flavored_router=False):
         self.fake_ovn_client._plugin.get_ports.return_value = [{
             'device_owner': n_const.DEVICE_OWNER_ROUTER_GW,
             'id': 'fake-id',
             'device_id': 'fake-device-id'}]
         self.fake_ovn_client._get_router_ports.return_value = []
         self.fake_ovn_client._plugin.get_networks.return_value = networks
+        if flavored_router:
+            self.fake_ovn_client._l3_plugin.get_router.return_value = {
+                'id': 'fake-id',
+                'flavor_id': 'fake-flavor-id'}
+        else:
+            self.fake_ovn_client._l3_plugin.get_router.return_value = {
+                'id': 'fake-id',
+                'flavor_id': None}
 
         lrp_redirect = fakes.FakeOvsdbRow.create_one_ovsdb_row(
             attrs={
@@ -779,21 +788,25 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
             periodics.NeverAgain,
             self.periodic.check_redirect_type_router_gateway_ports)
 
-        if redirect_value:
-            expected_calls = [
-                mock.call.db_set('Logical_Router_Port',
-                                 mock.ANY,
-                                 ('options', {'redirect-type': 'bridged'}))
-            ]
-            self.fake_ovn_client._nb_idl.db_set.assert_has_calls(
-                expected_calls)
+        if flavored_router:
+            self.fake_ovn_client._nb_idl.db_set.assert_not_called()
+            self.fake_ovn_client._nb_idl.db_remove.assert_not_called()
         else:
-            expected_calls = [
-                mock.call.db_remove('Logical_Router_Port', mock.ANY,
-                                    'options', 'redirect-type')
-            ]
-            self.fake_ovn_client._nb_idl.db_remove.assert_has_calls(
-                expected_calls)
+            if redirect_value:
+                expected_calls = [
+                    mock.call.db_set('Logical_Router_Port',
+                                     mock.ANY,
+                                     ('options', {'redirect-type': 'bridged'}))
+                ]
+                self.fake_ovn_client._nb_idl.db_set.assert_has_calls(
+                    expected_calls)
+            else:
+                expected_calls = [
+                    mock.call.db_remove('Logical_Router_Port', mock.ANY,
+                                        'options', 'redirect-type')
+                ]
+                self.fake_ovn_client._nb_idl.db_remove.assert_has_calls(
+                    expected_calls)
 
     def test_check_redirect_type_router_gateway_ports_enable_redirect(self):
         cfg.CONF.set_override('enable_distributed_floating_ip', 'True',
@@ -809,7 +822,19 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
                      'provider:network_type': n_const.TYPE_GENEVE}]
         self._test_check_redirect_type_router_gateway_ports(networks, False)
 
-    def _test_check_vlan_distributed_ports(self, opt_value=None):
+    def test_check_redirect_type_router_gateway_ports_flavored_router(self):
+        cfg.CONF.set_override('enable_distributed_floating_ip', 'True',
+                              group='ovn')
+        networks = [{'network_id': 'foo',
+                     'provider:network_type': n_const.TYPE_VLAN}]
+        self._test_check_redirect_type_router_gateway_ports(
+            networks, True, flavored_router=True)
+        networks = [{'network_id': 'foo',
+                     'provider:network_type': n_const.TYPE_GENEVE}]
+        self._test_check_redirect_type_router_gateway_ports(
+            networks, False, flavored_router=True)
+
+    def _test_check_provider_distributed_ports(self, opt_value=None):
         fake_net0 = {'id': 'net0'}
         fake_net1 = {'id': 'net1'}
         fake_port0 = {'id': 'port0', 'device_id': 'device0'}
@@ -831,18 +856,18 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
         # Invoke the periodic method, it meant to run only once at startup
         # so NeverAgain will be raised at the end
         self.assertRaises(periodics.NeverAgain,
-                          self.periodic.check_vlan_distributed_ports)
+                          self.periodic.check_provider_distributed_ports)
 
-    def test_check_vlan_distributed_ports_expected_value(self):
-        self._test_check_vlan_distributed_ports(opt_value='true')
+    def test_check_provider_distributed_ports_expected_value(self):
+        self._test_check_provider_distributed_ports(opt_value='true')
 
         # If the "reside-on-redirect-chassis" option value do match
         # the expected value, assert we do not update the database
         self.assertFalse(
             self.fake_ovn_client._nb_idl.db_set.called)
 
-    def test_check_vlan_distributed_ports_non_expected_value(self):
-        self._test_check_vlan_distributed_ports(opt_value='false')
+    def test_check_provider_distributed_ports_non_expected_value(self):
+        self._test_check_provider_distributed_ports(opt_value='false')
 
         # If the "reside-on-redirect-chassis" option value does not match
         # the expected value, assert we update the database
@@ -990,28 +1015,6 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
         self.fake_ovn_client._nb_idl.set_lswitch_port.assert_has_calls(
             expected_calls)
 
-    @mock.patch.object(utils, 'get_virtual_port_parents',
-                       return_value=[mock.ANY])
-    def test_update_port_virtual_type(self, *args):
-        nb_idl = self.fake_ovn_client._nb_idl
-        lsp0 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lsp0', 'type': ''})
-        lsp1 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lsp1', 'type': constants.LSP_TYPE_VIRTUAL})
-        lsp2 = fakes.FakeOvsdbRow.create_one_ovsdb_row(
-            attrs={'name': 'lsp2_not_present_in_neutron_db', 'type': ''})
-        port0 = {'fixed_ips': [{'ip_address': mock.ANY}],
-                 'network_id': mock.ANY, 'id': mock.ANY}
-        nb_idl.lsp_list.return_value.execute.return_value = (lsp0, lsp1, lsp2)
-        self.fake_ovn_client._plugin.get_port.side_effect = [
-            port0, n_exc.PortNotFound(port_id=mock.ANY)]
-
-        self.assertRaises(
-            periodics.NeverAgain, self.periodic.update_port_virtual_type)
-        expected_calls = [mock.call('Logical_Switch_Port', lsp0.uuid,
-                                    ('type', constants.LSP_TYPE_VIRTUAL))]
-        nb_idl.db_set.assert_has_calls(expected_calls)
-
     def test_add_gw_port_info_to_logical_router_port(self):
         nb_idl = self.fake_ovn_client._nb_idl
         ext_net_id = uuidutils.generate_uuid()
@@ -1101,13 +1104,13 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
         self.assertRaises(
             periodics.NeverAgain,
             self.periodic.check_router_default_route_empty_dst_ip)
-        nb_idl.delete_static_route.assert_has_calls([
-            mock.call(router1.name, route1.ip_prefix, route1.nexthop),
-            mock.call(router1.name, route3.ip_prefix, route3.nexthop),
+        nb_idl.delete_static_routes.assert_has_calls([
+            mock.call(router1.name, [(route1.ip_prefix, route1.nexthop),
+                                     (route3.ip_prefix, route3.nexthop)]),
         ])
         self.assertEqual(
-            2,
-            nb_idl.delete_static_route.call_count)
+            1,
+            nb_idl.delete_static_routes.call_count)
 
     @mock.patch.object(ports_obj.PortBinding, 'get_port_binding_by_vnic_type')
     def test_add_vnic_type_and_pb_capabilities_to_lsp(self, mock_get_pb):
@@ -1193,3 +1196,78 @@ class TestDBInconsistenciesPeriodics(testlib_api.SqlTestCaseLight,
             utils.ovn_name('lr-id-b'),
             lrb_nat['uuid'],
             gateway_port=lrp.uuid)
+
+    def test_check_network_broadcast_arps_to_all_routers(self):
+        cfg.CONF.set_override('broadcast_arps_to_all_routers', 'true',
+                              group='ovn')
+        networks = [{'id': 'foo', external_net.EXTERNAL: True}]
+        self.fake_ovn_client._plugin.get_networks.return_value = networks
+        fake_ls = mock.Mock(other_config={})
+        self.fake_ovn_client._nb_idl.get_lswitch.return_value = fake_ls
+
+        self.assertRaises(
+            periodics.NeverAgain,
+            self.periodic.check_network_broadcast_arps_to_all_routers)
+
+        self.fake_ovn_client._nb_idl.db_set.assert_called_once_with(
+            'Logical_Switch', 'neutron-foo', ('other_config',
+            {constants.LS_OPTIONS_BROADCAST_ARPS_ROUTERS: 'true'}))
+
+    def test_check_network_broadcast_arps_to_all_routers_already_set(self):
+        cfg.CONF.set_override('broadcast_arps_to_all_routers', 'false',
+                              group='ovn')
+        networks = [{'id': 'foo', external_net.EXTERNAL: True}]
+        self.fake_ovn_client._plugin.get_networks.return_value = networks
+        fake_ls = mock.Mock(other_config={
+            constants.LS_OPTIONS_BROADCAST_ARPS_ROUTERS: 'false'})
+        self.fake_ovn_client._nb_idl.get_lswitch.return_value = fake_ls
+
+        self.assertRaises(
+            periodics.NeverAgain,
+            self.periodic.check_network_broadcast_arps_to_all_routers)
+
+        # Assert there was no transactions because the value was already set
+        self.fake_ovn_client._nb_idl.db_set.assert_not_called()
+
+    def test_update_static_routes_with_external_ids(self):
+        _nb_idl = self.fake_ovn_client._nb_idl
+
+        sroute_a = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={'ip_prefix': '30.0.0.0/24', 'nexthop': '20.0.2.5',
+                   'external_ids': {}})
+        sroute_b = fakes.FakeOvsdbRow.create_one_ovsdb_row(
+            attrs={'ip_prefix': '30.1.0.0/24', 'nexthop': '20.0.2.6',
+                   'external_ids': {}})
+
+        self.fake_external_fixed_ips = {
+            'network_id': 'ext-network-id',
+            'external_fixed_ips': [{'ip_address': '20.0.2.1',
+                                    'subnet_id': 'ext-subnet-id'}]}
+        lrouter = {
+            'id': 'lr-test',
+            'routes': [{'nexthop': '20.0.2.5',
+                        'destination': '30.0.0.0/24'},
+                       {'nexthop': '20.0.2.6',
+                        'destination': '30.1.0.0/24'}],
+            'name': 'lr-test',
+            'admin_state_up': True,
+            'external_gateway_info': self.fake_external_fixed_ips
+        }
+        self.fake_ovn_client._l3_plugin.get_router.return_value = lrouter
+
+        expected = [{'name': 'lr-test',
+                     'static_routes': [sroute_a, sroute_b]}]
+        _nb_idl.get_all_logical_routers_static_routes.return_value = expected
+
+        # Call the maintenance task and check that the value has been
+        # updated in the external_ids
+        self.assertRaises(periodics.NeverAgain,
+            self.periodic.update_router_static_routes)
+
+        # Check static routes calls to verify if the maintenance task work
+        # as expected
+        external_ids = {constants.OVN_LRSR_EXT_ID_KEY: 'true'}
+        _nb_idl.set_static_route.assert_has_calls([
+            mock.call(sroute_a, external_ids=external_ids),
+            mock.call(sroute_b, external_ids=external_ids),
+        ])
